@@ -35,23 +35,23 @@ Adapter that uses the traits module to generate interfaces for ICA Analyzer.
 
 """
 
-import json
 import uuid
 
 import numpy
 from tvb.adapters.datatypes.db.mode_decompositions import IndependentComponentsIndex
 from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
 from tvb.adapters.datatypes.h5.mode_decompositions_h5 import IndependentComponentsH5
-from tvb.analyzers.ica import FastICA
+from tvb.analyzers.ica import compute_ica_decomposition
+from tvb.basic.neotraits.api import Int
 from tvb.core.adapters.abcadapter import ABCAdapterForm, ABCAdapter
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.neocom import h5
-from tvb.core.neotraits.forms import ScalarField, TraitDataTypeSelectField
+from tvb.core.neotraits.forms import TraitDataTypeSelectField, IntField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr
 from tvb.datatypes.time_series import TimeSeries
 
 
-class ICAAdapterModel(ViewModel, FastICA):
+class ICAAdapterModel(ViewModel):
     time_series = DataTypeGidAttr(
         linked_datatype=TimeSeries,
         label="Time Series",
@@ -59,15 +59,20 @@ class ICAAdapterModel(ViewModel, FastICA):
         doc="The timeseries to which the ICA is to be applied."
     )
 
+    n_components = Int(
+        label="Number of principal components to unmix.",
+        required=False,
+        default=None,
+        doc="Number of principal components to unmix.")
+
 
 class ICAAdapterForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(ICAAdapterForm, self).__init__(prefix, project_id)
-        self.time_series = TraitDataTypeSelectField(ICAAdapterModel.time_series, self, name='time_series',
+    def __init__(self):
+        super(ICAAdapterForm, self).__init__()
+        self.time_series = TraitDataTypeSelectField(ICAAdapterModel.time_series, name='time_series',
                                                     conditions=self.get_filters(), has_all_option=True)
-        self.n_components = ScalarField(ICAAdapterModel.n_components, self)
-        self.project_id = project_id
+        self.n_components = IntField(ICAAdapterModel.n_components)
 
     @staticmethod
     def get_view_model():
@@ -85,9 +90,6 @@ class ICAAdapterForm(ABCAdapterForm):
     def get_input_name():
         return "time_series"
 
-    def get_traited_datatype(self):
-        return FastICA()
-
 
 class ICAAdapter(ABCAdapter):
     """ TVB adapter for calling the ICA algorithm. """
@@ -115,15 +117,9 @@ class ICAAdapter(ABCAdapter):
                             self.input_time_series_index.data_length_4d)
         self.log.debug("Time series shape is %s" % str(self.input_shape))
         self.log.debug("Provided number of components is %s" % view_model.n_components)
-        # -------------------- Fill Algorithm for Analysis -------------------##
 
-        algorithm = FastICA()
-        if view_model.n_components is not None:
-            algorithm.n_components = view_model.n_components
-        else:
-            # It will only work for Simulator results.
-            algorithm.n_components = self.input_time_series_index.data_length_3d
-        self.algorithm = algorithm
+        if view_model.n_components is None:
+            view_model.n_components = self.input_time_series_index.data_length_3d
 
     def get_required_memory_size(self, view_model):
         # type: (ICAAdapterModel) -> int
@@ -132,7 +128,7 @@ class ICAAdapter(ABCAdapter):
         """
         used_shape = (self.input_shape[0], 1, self.input_shape[2], self.input_shape[3])
         input_size = numpy.prod(used_shape) * 8.0
-        output_size = self.algorithm.result_size(self.input_shape)
+        output_size = self.result_size(self.input_shape, view_model.n_components)
         return input_size + output_size
 
     def get_required_disk_size(self, view_model):
@@ -141,26 +137,22 @@ class ICAAdapter(ABCAdapter):
         Returns the required disk size to be able to run the adapter (in kB).
         """
         used_shape = (self.input_shape[0], 1, self.input_shape[2], self.input_shape[3])
-        return self.array_size2kb(self.algorithm.result_size(used_shape))
+        return self.array_size2kb(self.result_size(used_shape, view_model.n_components))
 
     def launch(self, view_model):
         # type: (ICAAdapterModel) -> [IndependentComponentsIndex]
-        """ 
-        Launch algorithm and build results. 
         """
-        # --------- Prepare a IndependentComponents object for result ----------##
+        Launch algorithm and build results.
+        :param view_model: the ViewModel keeping the algorithm inputs
+        :return: the ica index for the specified time series
+        """
+        # --------------------- Prepare result entities ---------------------##
         ica_index = IndependentComponentsIndex()
-        ica_index.fk_source_gid = view_model.time_series.hex
-
-        time_series_h5 = h5.h5_file_for_index(self.input_time_series_index)
-
         result_path = h5.path_for(self.storage_path, IndependentComponentsH5, ica_index.gid)
         ica_h5 = IndependentComponentsH5(path=result_path)
-        ica_h5.gid.store(uuid.UUID(ica_index.gid))
-        ica_h5.source.store(view_model.time_series)
-        ica_h5.n_components.store(self.algorithm.n_components)
 
         # ------------- NOTE: Assumes 4D, Simulator timeSeries. --------------##
+        time_series_h5 = h5.h5_file_for_index(self.input_time_series_index)
         input_shape = time_series_h5.data.shape
         node_slice = [slice(input_shape[0]), None, slice(input_shape[2]), slice(input_shape[3])]
 
@@ -169,14 +161,27 @@ class ICAAdapter(ABCAdapter):
         for var in range(input_shape[1]):
             node_slice[1] = slice(var, var + 1)
             small_ts.data = time_series_h5.read_data_slice(tuple(node_slice))
-            self.algorithm.time_series = small_ts
-            partial_ica = self.algorithm.evaluate()
+            partial_ica = compute_ica_decomposition(small_ts, view_model.n_components)
             ica_h5.write_data_slice(partial_ica)
-        array_metadata = ica_h5.unmixing_matrix.get_cached_metadata()
-        ica_index.array_has_complex = array_metadata.has_complex
-        ica_index.shape = json.dumps(ica_h5.unmixing_matrix.shape)
-        ica_index.ndim = len(ica_h5.unmixing_matrix.shape)
-        ica_h5.close()
+
         time_series_h5.close()
 
+        partial_ica.source.gid = view_model.time_series
+        partial_ica.gid = uuid.UUID(ica_index.gid)
+
+        ica_h5.store(partial_ica, scalars_only=True)
+        ica_h5.close()
+
+        ica_index.fill_from_has_traits(partial_ica)
+
         return ica_index
+
+    @staticmethod
+    def result_shape(input_shape, n_components):
+        """Returns the shape of the mixing matrix."""
+        n = n_components or input_shape[2]
+        return n, n, input_shape[1], input_shape[3]
+
+    def result_size(self, input_shape, n_components):
+        """Returns the storage size in bytes of the mixing matrix of the ICA analysis, assuming 64-bit float."""
+        return numpy.prod(self.result_shape(input_shape, n_components)) * 8
