@@ -36,11 +36,13 @@
 from tvb.adapters.datatypes.db.local_connectivity import LocalConnectivityIndex
 from tvb.adapters.datatypes.db.surface import SurfaceIndex
 from tvb.adapters.simulator.equation_forms import GaussianEquationForm, get_form_for_equation
+from tvb.adapters.simulator.subforms_mapping import GAUSSIAN_EQUATION, get_ui_name_to_equation_dict, \
+    DOUBLE_GAUSSIAN_EQUATION, SIGMOID_EQUATION
 from tvb.basic.neotraits.api import Attr
 from tvb.core.adapters.abcadapter import ABCAdapterForm, ABCAdapter
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.neocom import h5
-from tvb.core.neotraits.forms import ScalarField, FormField, SelectField, TraitDataTypeSelectField
+from tvb.core.neotraits.forms import FormField, SelectField, TraitDataTypeSelectField, FloatField, StrField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr, Str
 from tvb.datatypes.local_connectivity import LocalConnectivity
 from tvb.datatypes.surfaces import Surface, CORTICAL
@@ -48,10 +50,10 @@ from tvb.datatypes.surfaces import Surface, CORTICAL
 
 class LocalConnectivitySelectorForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(LocalConnectivitySelectorForm, self).__init__(prefix, project_id)
+    def __init__(self):
+        super(LocalConnectivitySelectorForm, self).__init__()
         traited_attr = Attr(self.get_required_datatype(), label='Load Local Connectivity', required=False)
-        self.existentEntitiesSelect = TraitDataTypeSelectField(traited_attr, self, name='existentEntitiesSelect')
+        self.existentEntitiesSelect = TraitDataTypeSelectField(traited_attr, name='existentEntitiesSelect')
 
     @staticmethod
     def get_required_datatype():
@@ -83,15 +85,19 @@ class LocalConnectivityCreatorModel(ViewModel, LocalConnectivity):
 
 class LocalConnectivityCreatorForm(ABCAdapterForm):
     NAME_EQUATION_PARAMS_DIV = 'spatial_params'
+    possible_equations = {GAUSSIAN_EQUATION: get_ui_name_to_equation_dict().get(GAUSSIAN_EQUATION),
+                          DOUBLE_GAUSSIAN_EQUATION: get_ui_name_to_equation_dict().get(DOUBLE_GAUSSIAN_EQUATION),
+                          SIGMOID_EQUATION: get_ui_name_to_equation_dict().get(SIGMOID_EQUATION)}
 
-    def __init__(self, equation_choices, prefix='', project_id=None):
-        super(LocalConnectivityCreatorForm, self).__init__(prefix, project_id)
-        self.surface = TraitDataTypeSelectField(LocalConnectivityCreatorModel.surface, self, name=self.get_input_name(),
+    def __init__(self):
+        super(LocalConnectivityCreatorForm, self).__init__()
+        self.surface = TraitDataTypeSelectField(LocalConnectivityCreatorModel.surface, name=self.get_input_name(),
                                                 conditions=self.get_filters())
-        self.spatial = SelectField(LocalConnectivityCreatorModel.equation, self, name='spatial',
-                                   choices=equation_choices, display_none_choice=False, subform=GaussianEquationForm)
-        self.cutoff = ScalarField(LocalConnectivityCreatorModel.cutoff, self)
-        self.display_name = ScalarField(LocalConnectivityCreatorModel.display_name, self, name='display_name')
+        self.spatial = SelectField(LocalConnectivityCreatorModel.equation, name='spatial',
+                                   choices=self.possible_equations,
+                                   display_none_choice=False, subform=GaussianEquationForm)
+        self.cutoff = FloatField(LocalConnectivityCreatorModel.cutoff)
+        self.display_name = StrField(LocalConnectivityCreatorModel.display_name, name='display_name')
 
     @staticmethod
     def get_view_model():
@@ -110,9 +116,6 @@ class LocalConnectivityCreatorForm(ABCAdapterForm):
         return FilterChain(fields=[FilterChain.datatype + '.surface_type'], operations=["=="],
                            values=[CORTICAL])
 
-    def get_traited_datatype(self):
-        return LocalConnectivityCreatorModel()
-
     def fill_from_trait(self, trait):
         # type: (LocalConnectivityCreatorModel) -> None
         self.surface.data = trait.surface.hex
@@ -123,8 +126,7 @@ class LocalConnectivityCreatorForm(ABCAdapterForm):
         else:
             lc_equation = LocalConnectivity.equation.default
         self.spatial.data = type(lc_equation)
-        self.spatial.subform_field = FormField(get_form_for_equation(type(lc_equation)), self,
-                                               self.NAME_EQUATION_PARAMS_DIV)
+        self.spatial.subform_field = FormField(get_form_for_equation(type(lc_equation)), self.NAME_EQUATION_PARAMS_DIV)
         self.spatial.subform_field.form.fill_from_trait(lc_equation)
 
     def get_rendering_dict(self):
