@@ -33,10 +33,12 @@
 """
 
 import json
-from sqlalchemy.orm import relationship
+
 from sqlalchemy import Column, String, Integer, ForeignKey
+from sqlalchemy.orm import relationship
 from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
 from tvb.adapters.datatypes.h5.mapped_value_h5 import ValueWrapper
+from tvb.core.entities.file.simulator.datatype_measure_h5 import DatatypeMeasure
 from tvb.core.entities.model.model_datatype import DataType
 
 
@@ -85,3 +87,9 @@ class DatatypeMeasureIndex(DataType):
                 result = result + " -- " + entry + ' : ' + str(metric_value)
 
         return result
+
+    def fill_from_has_traits(self, datatype):
+        # type: (DatatypeMeasure)  -> None
+        super(DatatypeMeasureIndex, self).fill_from_has_traits(datatype)
+        self.metrics = json.dumps(datatype.metrics)
+        self.fk_source_gid = datatype.analyzed_datatype.gid.hex
