@@ -33,7 +33,7 @@ from tvb.basic.neotraits.api import List
 from tvb.core.entities.file.simulator.view_model import *
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.entities.load import load_entity_by_gid
-from tvb.core.neotraits.forms import Form, ScalarField, ArrayField, MultiSelectField
+from tvb.core.neotraits.forms import Form, ArrayField, MultiSelectField, FloatField, StrField
 from tvb.core.neotraits.forms import SelectField, TraitDataTypeSelectField
 from tvb.datatypes.projections import ProjectionsType
 from tvb.datatypes.sensors import SensorTypes
@@ -41,16 +41,16 @@ from tvb.datatypes.sensors import SensorTypes
 
 def get_monitor_to_form_dict():
     monitor_class_to_form = {
-        RawViewModel: RawMonitorForm,
-        SubSampleViewModel: SubSampleMonitorForm,
+        RawViewModel: MonitorForm,
+        SubSampleViewModel: MonitorForm,
         SpatialAverageViewModel: SpatialAverageMonitorForm,
-        GlobalAverageViewModel: GlobalAverageMonitorForm,
-        TemporalAverageViewModel: TemporalAverageMonitorForm,
+        GlobalAverageViewModel: MonitorForm,
+        TemporalAverageViewModel: MonitorForm,
         EEGViewModel: EEGMonitorForm,
         MEGViewModel: MEGMonitorForm,
         iEEGViewModel: iEEGMonitorForm,
         BoldViewModel: BoldMonitorForm,
-        BoldRegionROIViewModel: BoldRegionROIMonitorForm
+        BoldRegionROIViewModel: BoldMonitorForm
     }
 
     return monitor_class_to_form
@@ -86,11 +86,10 @@ def get_form_for_monitor(monitor_class):
 
 class MonitorForm(Form):
 
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(MonitorForm, self).__init__(prefix, project_id)
+    def __init__(self, session_stored_simulator=None):
+        super(MonitorForm, self).__init__()
         self.session_stored_simulator = session_stored_simulator
-        self.project_id = project_id
-        self.period = ScalarField(Monitor.period, self)
+        self.period = FloatField(Monitor.period)
         self.variables_of_interest_indexes = {}
 
         if session_stored_simulator is not None:
@@ -99,7 +98,7 @@ class MonitorForm(Form):
 
         self.variables_of_interest = MultiSelectField(List(of=str, label='Model Variables to watch',
                                                            choices=tuple(self.variables_of_interest_indexes.keys())),
-                                                      self, name='variables_of_interest')
+                                                    name='variables_of_interest')
 
     def fill_from_trait(self, trait):
         super(MonitorForm, self).fill_from_trait(trait)
@@ -138,27 +137,13 @@ class MonitorForm(Form):
             variables_of_interest_indexes[variable] = all_variables.index(variable)
         return variables_of_interest_indexes
 
-    # TODO: We should review the code here, we could probably reduce the number of  classes that are used here
-
-
-class RawMonitorForm(Form):
-
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(RawMonitorForm, self).__init__(prefix, project_id)
-
-
-class SubSampleMonitorForm(MonitorForm):
-
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(SubSampleMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
-
 
 class SpatialAverageMonitorForm(MonitorForm):
 
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(SpatialAverageMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
-        self.spatial_mask = ArrayField(SpatialAverage.spatial_mask, self)
-        self.default_mask = ScalarField(SpatialAverage.default_mask, self)
+    def __init__(self, session_stored_simulator=None):
+        super(SpatialAverageMonitorForm, self).__init__(session_stored_simulator)
+        self.spatial_mask = ArrayField(SpatialAverage.spatial_mask)
+        self.default_mask = SelectField(SpatialAverage.default_mask)
 
     def fill_from_trait(self, trait):
         super(SpatialAverageMonitorForm, self).fill_from_trait(trait)
@@ -178,36 +163,24 @@ class SpatialAverageMonitorForm(MonitorForm):
             self.default_mask.disabled = True
 
 
-class GlobalAverageMonitorForm(MonitorForm):
-
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(GlobalAverageMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
-
-
-class TemporalAverageMonitorForm(MonitorForm):
-
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(TemporalAverageMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
-
-
 class ProjectionMonitorForm(MonitorForm):
 
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(ProjectionMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
+    def __init__(self, session_stored_simulator=None):
+        super(ProjectionMonitorForm, self).__init__(session_stored_simulator)
 
         rm_filter = None
-        if session_stored_simulator.is_surface_simulation:
+        if session_stored_simulator and session_stored_simulator.is_surface_simulation:
             rm_filter = FilterChain(fields=[FilterChain.datatype + '.gid'], operations=['=='],
                                     values=[session_stored_simulator.surface.region_mapping_data.hex])
 
-        self.region_mapping = TraitDataTypeSelectField(ProjectionViewModel.region_mapping, self,
-                                                       name='region_mapping', conditions=rm_filter)
+        self.region_mapping = TraitDataTypeSelectField(ProjectionViewModel.region_mapping, name='region_mapping',
+                                                       conditions=rm_filter)
 
 
 class EEGMonitorForm(ProjectionMonitorForm):
 
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(EEGMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
+    def __init__(self, session_stored_simulator=None):
+        super(EEGMonitorForm, self).__init__(session_stored_simulator)
 
         sensor_filter = FilterChain(fields=[FilterChain.datatype + '.sensors_type'], operations=["=="],
                                     values=[SensorTypes.TYPE_EEG.value])
@@ -215,17 +188,17 @@ class EEGMonitorForm(ProjectionMonitorForm):
         projection_filter = FilterChain(fields=[FilterChain.datatype + '.projection_type'], operations=["=="],
                                         values=[ProjectionsType.EEG.value])
 
-        self.projection = TraitDataTypeSelectField(EEGViewModel.projection, self, name='projection',
+        self.projection = TraitDataTypeSelectField(EEGViewModel.projection, name='projection',
                                                    conditions=projection_filter)
-        self.reference = ScalarField(EEG.reference, self)
-        self.sensors = TraitDataTypeSelectField(EEGViewModel.sensors, self, name='sensors', conditions=sensor_filter)
-        self.sigma = ScalarField(EEG.sigma, self)
+        self.reference = StrField(EEG.reference)
+        self.sensors = TraitDataTypeSelectField(EEGViewModel.sensors, name='sensors', conditions=sensor_filter)
+        self.sigma = FloatField(EEG.sigma)
 
 
 class MEGMonitorForm(ProjectionMonitorForm):
 
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(MEGMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
+    def __init__(self, session_stored_simulator=None):
+        super(MEGMonitorForm, self).__init__(session_stored_simulator)
 
         sensor_filter = FilterChain(fields=[FilterChain.datatype + '.sensors_type'], operations=["=="],
                                     values=[SensorTypes.TYPE_MEG.value])
@@ -233,15 +206,15 @@ class MEGMonitorForm(ProjectionMonitorForm):
         projection_filter = FilterChain(fields=[FilterChain.datatype + '.projection_type'], operations=["=="],
                                         values=[ProjectionsType.MEG.value])
 
-        self.projection = TraitDataTypeSelectField(MEGViewModel.projection, self, name='projection',
+        self.projection = TraitDataTypeSelectField(MEGViewModel.projection, name='projection',
                                                    conditions=projection_filter)
-        self.sensors = TraitDataTypeSelectField(MEGViewModel.sensors, self, name='sensors', conditions=sensor_filter)
+        self.sensors = TraitDataTypeSelectField(MEGViewModel.sensors, name='sensors', conditions=sensor_filter)
 
 
 class iEEGMonitorForm(ProjectionMonitorForm):
 
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(iEEGMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
+    def __init__(self, session_stored_simulator=None):
+        super(iEEGMonitorForm, self).__init__(session_stored_simulator)
 
         sensor_filter = FilterChain(fields=[FilterChain.datatype + '.sensors_type'], operations=["=="],
                                     values=[SensorTypes.TYPE_INTERNAL.value])
@@ -249,22 +222,22 @@ class iEEGMonitorForm(ProjectionMonitorForm):
         projection_filter = FilterChain(fields=[FilterChain.datatype + '.projection_type'], operations=["=="],
                                         values=[ProjectionsType.SEEG.value])
 
-        self.projection = TraitDataTypeSelectField(iEEGViewModel.projection, self, name='projection',
+        self.projection = TraitDataTypeSelectField(iEEGViewModel.projection, name='projection',
                                                    conditions=projection_filter)
-        self.sigma = ScalarField(iEEG.sigma, self)
-        self.sensors = TraitDataTypeSelectField(iEEGViewModel.sensors, self, name='sensors', conditions=sensor_filter)
+        self.sigma = FloatField(iEEG.sigma)
+        self.sensors = TraitDataTypeSelectField(iEEGViewModel.sensors, name='sensors', conditions=sensor_filter)
 
 
 class BoldMonitorForm(MonitorForm):
 
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(BoldMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
+    def __init__(self, session_stored_simulator=None):
+        super(BoldMonitorForm, self).__init__(session_stored_simulator)
         self.hrf_kernel_choices = get_ui_name_to_monitor_equation_dict()
         default_hrf_kernel = list(self.hrf_kernel_choices.values())[0]
 
-        self.period = ScalarField(Bold.period, self)
+        self.period = FloatField(Bold.period)
         self.hrf_kernel = SelectField(Attr(HRFKernelEquation, label='Equation', default=default_hrf_kernel),
-                                      self, name='hrf_kernel', choices=self.hrf_kernel_choices)
+                                    name='hrf_kernel', choices=self.hrf_kernel_choices)
 
     def fill_trait(self, datatype):
         super(BoldMonitorForm, self).fill_trait(datatype)
@@ -275,9 +248,3 @@ class BoldMonitorForm(MonitorForm):
     def fill_from_trait(self, trait):
         super(BoldMonitorForm, self).fill_from_trait(trait)
         self.hrf_kernel.data = trait.hrf_kernel.__class__
-
-
-class BoldRegionROIMonitorForm(BoldMonitorForm):
-
-    def __init__(self, session_stored_simulator=None, prefix='', project_id=None):
-        super(BoldRegionROIMonitorForm, self).__init__(session_stored_simulator, prefix, project_id)
