@@ -46,11 +46,11 @@ class EEGMatTimeSeriesImporterModel(UploaderViewModel):
 
 class EEGRegionMatTimeSeriesImporterForm(RegionMatTimeSeriesImporterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(EEGRegionMatTimeSeriesImporterForm, self).__init__(prefix, project_id)
+    def __init__(self):
+        super(EEGRegionMatTimeSeriesImporterForm, self).__init__()
         eeg_conditions = FilterChain(fields=[FilterChain.datatype + '.sensors_type'], operations=['=='],
                                      values=[SensorTypes.TYPE_EEG.value])
-        self.datatype = TraitDataTypeSelectField(EEGMatTimeSeriesImporterModel.datatype, self, name='tstype_parameters',
+        self.datatype = TraitDataTypeSelectField(EEGMatTimeSeriesImporterModel.datatype, name='tstype_parameters',
                                                  conditions=eeg_conditions)
 
     @staticmethod
