@@ -102,17 +102,16 @@ class RegionMatTimeSeriesImporterModel(UploaderViewModel):
 
 class RegionMatTimeSeriesImporterForm(ABCUploaderForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(RegionMatTimeSeriesImporterForm, self).__init__(prefix, project_id)
-        self.data_file = TraitUploadField(RegionMatTimeSeriesImporterModel.data_file, '.mat', self, name='data_file')
-        self.dataset_name = StrField(RegionMatTimeSeriesImporterModel.dataset_name, self, name='dataset_name')
-        self.structure_path = StrField(RegionMatTimeSeriesImporterModel.structure_path, self, name='structure_path')
-        self.transpose = BoolField(RegionMatTimeSeriesImporterModel.transpose, self, name='transpose')
-        self.slice = StrField(RegionMatTimeSeriesImporterModel.slice, self, name='slice')
-        self.sampling_rate = IntField(RegionMatTimeSeriesImporterModel.sampling_rate, self, name='sampling_rate')
-        self.start_time = IntField(RegionMatTimeSeriesImporterModel.start_time, self, name='start_time')
-        self.datatype = TraitDataTypeSelectField(RegionMatTimeSeriesImporterModel.datatype, self,
-                                                 name='tstype_parameters')
+    def __init__(self):
+        super(RegionMatTimeSeriesImporterForm, self).__init__()
+        self.data_file = TraitUploadField(RegionMatTimeSeriesImporterModel.data_file, '.mat', 'data_file')
+        self.dataset_name = StrField(RegionMatTimeSeriesImporterModel.dataset_name, name='dataset_name')
+        self.structure_path = StrField(RegionMatTimeSeriesImporterModel.structure_path, name='structure_path')
+        self.transpose = BoolField(RegionMatTimeSeriesImporterModel.transpose, name='transpose')
+        self.slice = StrField(RegionMatTimeSeriesImporterModel.slice, name='slice')
+        self.sampling_rate = IntField(RegionMatTimeSeriesImporterModel.sampling_rate, name='sampling_rate')
+        self.start_time = IntField(RegionMatTimeSeriesImporterModel.start_time, name='start_time')
+        self.datatype = TraitDataTypeSelectField(RegionMatTimeSeriesImporterModel.datatype, name='tstype_parameters')
 
     @staticmethod
     def get_view_model():
