@@ -71,15 +71,15 @@ class ConnectivityAnnotationsViewModel(ViewModel):
 
 class ConnectivityAnnotationsViewForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(ConnectivityAnnotationsViewForm, self).__init__(prefix, project_id)
+    def __init__(self):
+        super(ConnectivityAnnotationsViewForm, self).__init__()
         # Used for filtering
-        self.connectivity_index = TraitDataTypeSelectField(ConnectivityAnnotationsViewModel.connectivity_index, self,
+        self.connectivity_index = TraitDataTypeSelectField(ConnectivityAnnotationsViewModel.connectivity_index,
                                                            'connectivity_index')
-        self.annotations_index = TraitDataTypeSelectField(ConnectivityAnnotationsViewModel.annotations_index, self,
+        self.annotations_index = TraitDataTypeSelectField(ConnectivityAnnotationsViewModel.annotations_index,
                                                           'annotations_index', conditions=self.get_filters())
         self.region_mapping_index = TraitDataTypeSelectField(ConnectivityAnnotationsViewModel.region_mapping_index,
-                                                             self, 'region_mapping_index')
+                                                             'region_mapping_index')
 
     @staticmethod
     def get_view_model():
