@@ -111,32 +111,24 @@ class ConnectivityViewerModel(ViewModel):
 
 class ConnectivityViewerForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(ConnectivityViewerForm, self).__init__(prefix, project_id)
+    def __init__(self):
+        super(ConnectivityViewerForm, self).__init__()
 
-        # filters_ui = [UIFilter(linked_elem_name="colors",
-        #                        linked_elem_field=FilterChain.datatype + "._connectivity"),
-        #               UIFilter(linked_elem_name="rays",
-        #                        linked_elem_field=FilterChain.datatype + "._connectivity")]
-        # json_ui_filter = json.dumps([ui_filter.to_dict() for ui_filter in filters_ui])
-        # KWARG_FILTERS_UI: json_ui_filter
-
-        self.connectivity = TraitDataTypeSelectField(ConnectivityViewerModel.connectivity, self, name='input_data',
+        self.connectivity = TraitDataTypeSelectField(ConnectivityViewerModel.connectivity, name='input_data',
                                                      conditions=self.get_filters())
         surface_conditions = FilterChain(fields=[FilterChain.datatype + '.surface_type'], operations=["=="],
                                          values=['Cortical Surface'])
-        self.surface_data = TraitDataTypeSelectField(ConnectivityViewerModel.surface_data, self, name='surface_data',
+        self.surface_data = TraitDataTypeSelectField(ConnectivityViewerModel.surface_data, name='surface_data',
                                                      conditions=surface_conditions)
 
-        self.step = FloatField(ConnectivityViewerModel.step, self, name='step')
+        self.step = FloatField(ConnectivityViewerModel.step, name='step')
 
         colors_conditions = FilterChain(fields=[FilterChain.datatype + '.ndim'], operations=["=="], values=[1])
-        self.colors = TraitDataTypeSelectField(ConnectivityViewerModel.colors, self, name='colors',
+        self.colors = TraitDataTypeSelectField(ConnectivityViewerModel.colors, name='colors',
                                                conditions=colors_conditions)
 
         rays_conditions = FilterChain(fields=[FilterChain.datatype + '.ndim'], operations=["=="], values=[1])
-        self.rays = TraitDataTypeSelectField(ConnectivityViewerModel.rays, self, name='rays',
-                                             conditions=rays_conditions)
+        self.rays = TraitDataTypeSelectField(ConnectivityViewerModel.rays, name='rays', conditions=rays_conditions)
 
     @staticmethod
     def get_view_model():
@@ -380,14 +372,20 @@ class Connectivity2DViewer(object):
         norm_rays, min_ray, max_ray = self._normalize_rays(rays, input_data.number_of_regions)
         colors, step = self._prepare_colors(colors, input_data.number_of_regions, step)
 
-        right_json = self._get_json(input_data.ordered_labels[input_data.hemispheres],
-                                    input_data.ordered_centres[input_data.hemispheres], weights[1],
-                                    math.pi, 1, 2, numpy.asarray(norm_rays)[input_data.hemispheres],
-                                    numpy.asarray(colors)[input_data.hemispheres], X_CANVAS_SMALL, Y_CANVAS_SMALL)
-        left_json = self._get_json(input_data.ordered_labels[~input_data.hemispheres],
-                                   input_data.ordered_centres[~input_data.hemispheres], weights[0],
-                                   math.pi, 1, 2, numpy.asarray(norm_rays)[~input_data.hemispheres],
-                                   numpy.asarray(colors)[~input_data.hemispheres], X_CANVAS_SMALL, Y_CANVAS_SMALL)
+        if numpy.all((input_data.hemispheres == False)):
+            right_json = ""
+        else:
+            right_json = self._get_json(input_data.ordered_labels[input_data.hemispheres],
+                                        input_data.ordered_centres[input_data.hemispheres], weights[1],
+                                        math.pi, 1, 2, numpy.asarray(norm_rays)[input_data.hemispheres],
+                                        numpy.asarray(colors)[input_data.hemispheres], X_CANVAS_SMALL, Y_CANVAS_SMALL)
+        if numpy.all((input_data.hemispheres == True)):
+            left_json = ""
+        else:
+            left_json = self._get_json(input_data.ordered_labels[~input_data.hemispheres],
+                                       input_data.ordered_centres[~input_data.hemispheres], weights[0],
+                                       math.pi, 1, 2, numpy.asarray(norm_rays)[~input_data.hemispheres],
+                                       numpy.asarray(colors)[~input_data.hemispheres], X_CANVAS_SMALL, Y_CANVAS_SMALL)
         full_json = self._get_json(input_data.ordered_labels, input_data.ordered_centres, normalized_weights,
                                    math.pi, 0, 1, norm_rays, colors, X_CANVAS_FULL, Y_CANVAS_FULL)
 
