@@ -55,9 +55,9 @@ class CrossCoherenceVisualizerModel(ViewModel):
 
 class CrossCoherenceVisualizerForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(CrossCoherenceVisualizerForm, self).__init__(prefix, project_id)
-        self.datatype = TraitDataTypeSelectField(CrossCoherenceVisualizerModel.datatype, self, name='datatype',
+    def __init__(self):
+        super(CrossCoherenceVisualizerForm, self).__init__()
+        self.datatype = TraitDataTypeSelectField(CrossCoherenceVisualizerModel.datatype, name='datatype',
                                                  conditions=self.get_filters())
 
     @staticmethod
