@@ -159,11 +159,11 @@ class MatrixVisualizerModel(ViewModel):
 
 class MatrixVisualizerForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(MatrixVisualizerForm, self).__init__(prefix, project_id, False)
-        self.datatype = TraitDataTypeSelectField(MatrixVisualizerModel.datatype, self, name='datatype',
+    def __init__(self):
+        super(MatrixVisualizerForm, self).__init__()
+        self.datatype = TraitDataTypeSelectField(MatrixVisualizerModel.datatype, name='datatype',
                                                  conditions=self.get_filters())
-        self.slice = StrField(MatrixVisualizerModel.slice, self, name='slice')
+        self.slice = StrField(MatrixVisualizerModel.slice, name='slice')
 
     @staticmethod
     def get_view_model():
