@@ -110,10 +110,10 @@ class IsoclinePSEAdapterModel(ViewModel):
 
 class IsoclinePSEAdapterForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(IsoclinePSEAdapterForm, self).__init__(prefix, project_id)
-        self.datatype_group = TraitDataTypeSelectField(IsoclinePSEAdapterModel.datatype_group, self,
-                                                       name='datatype_group', conditions=self.get_filters())
+    def __init__(self):
+        super(IsoclinePSEAdapterForm, self).__init__()
+        self.datatype_group = TraitDataTypeSelectField(IsoclinePSEAdapterModel.datatype_group, name='datatype_group',
+                                                       conditions=self.get_filters())
 
     @staticmethod
     def get_view_model():
