@@ -283,9 +283,9 @@ class BaseVolumeVisualizerModel(ViewModel):
 @add_metaclass(ABCMeta)
 class BaseVolumeVisualizerForm(ABCAdapterForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(BaseVolumeVisualizerForm, self).__init__(prefix, project_id)
-        self.background = TraitDataTypeSelectField(BaseVolumeVisualizerModel.background, self, name='background')
+    def __init__(self):
+        super(BaseVolumeVisualizerForm, self).__init__()
+        self.background = TraitDataTypeSelectField(BaseVolumeVisualizerModel.background, name='background')
 
 
 class VolumeVisualizerModel(BaseVolumeVisualizerModel):
@@ -310,13 +310,13 @@ class VolumeVisualizerModel(BaseVolumeVisualizerModel):
 
 class VolumeVisualizerForm(BaseVolumeVisualizerForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(VolumeVisualizerForm, self).__init__(prefix, project_id)
-        self.measure = TraitDataTypeSelectField(VolumeVisualizerModel.measure, self, name='measure',
+    def __init__(self):
+        super(VolumeVisualizerForm, self).__init__()
+        self.measure = TraitDataTypeSelectField(VolumeVisualizerModel.measure, name='measure',
                                                 conditions=self.get_filters())
-        self.region_mapping_volume = TraitDataTypeSelectField(VolumeVisualizerModel.region_mapping_volume, self,
+        self.region_mapping_volume = TraitDataTypeSelectField(VolumeVisualizerModel.region_mapping_volume,
                                                               name='region_mapping_volume')
-        self.data_slice = StrField(VolumeVisualizerModel.data_slice, self, name='data_slice')
+        self.data_slice = StrField(VolumeVisualizerModel.data_slice, name='data_slice')
 
     @staticmethod
     def get_view_model():
@@ -383,13 +383,13 @@ class ConnectivityMeasureVolumeVisualizerModel(BaseVolumeVisualizerModel):
 
 class ConnectivityMeasureVolumeVisualizerForm(BaseVolumeVisualizerForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(ConnectivityMeasureVolumeVisualizerForm, self).__init__(prefix, project_id)
+    def __init__(self):
+        super(ConnectivityMeasureVolumeVisualizerForm, self).__init__()
         self.connectivity_measure = TraitDataTypeSelectField(
-            ConnectivityMeasureVolumeVisualizerModel.connectivity_measure, self, name='connectivity_measure',
+            ConnectivityMeasureVolumeVisualizerModel.connectivity_measure, name='connectivity_measure',
             conditions=self.get_filters())
         self.region_mapping_volume = TraitDataTypeSelectField(
-            ConnectivityMeasureVolumeVisualizerModel.region_mapping_volume, self, name='region_mapping_volume')
+            ConnectivityMeasureVolumeVisualizerModel.region_mapping_volume, name='region_mapping_volume')
 
     @staticmethod
     def get_view_model():
@@ -452,18 +452,17 @@ class RegionVolumeMappingVisualiserModel(BaseVolumeVisualizerModel):
 
 class RegionVolumeMappingVisualiserForm(BaseVolumeVisualizerForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(RegionVolumeMappingVisualiserForm, self).__init__(prefix, project_id)
+    def __init__(self):
+        super(RegionVolumeMappingVisualiserForm, self).__init__()
         self.region_mapping_volume = TraitDataTypeSelectField(RegionVolumeMappingVisualiserModel.region_mapping_volume,
-                                                              self, name='region_mapping_volume',
+                                                              name='region_mapping_volume',
                                                               conditions=self.get_filters())
 
         cm_conditions = FilterChain(
             fields=[FilterChain.datatype + '.ndim', FilterChain.datatype + '.has_volume_mapping'],
             operations=["==", "=="], values=[1, True])
         self.connectivity_measure = TraitDataTypeSelectField(RegionVolumeMappingVisualiserModel.connectivity_measure,
-                                                             self, name='connectivity_measure',
-                                                             conditions=cm_conditions)
+                                                             name='connectivity_measure', conditions=cm_conditions)
 
     @staticmethod
     def get_view_model():
@@ -511,8 +510,8 @@ class RegionVolumeMappingVisualiser(_MappedArrayVolumeBase):
 
 class MriVolumeVisualizerForm(BaseVolumeVisualizerForm):
 
-    def __init__(self, prefix='', project_id=None):
-        super(MriVolumeVisualizerForm, self).__init__(prefix, project_id)
+    def __init__(self):
+        super(MriVolumeVisualizerForm, self).__init__()
         self.background.required = True
 
     @staticmethod
