@@ -42,6 +42,7 @@ from sqlalchemy.orm.exc import NoResultFound
 from sqlalchemy.sql.expression import case as case_, desc
 from tvb.core.entities.model.model_datatype import DataType
 from tvb.core.entities.model.model_operation import *
+from tvb.core.entities.model.model_operation import STATUS_ERROR
 from tvb.core.entities.storage.root_dao import RootDAO, DEFAULT_PAGE_SIZE
 
 
@@ -166,6 +167,19 @@ class OperationDAO(RootDAO):
         return result
 
 
+    def get_operations_with_error_in_project(self, project_id):
+        """
+        Retrieve OPERATION with errors entities for a given project.
+        """
+        result = None
+        try:
+            query = self.session.query(Operation).filter_by(fk_launched_in=project_id).filter(
+                Operation.status == STATUS_ERROR)
+            result = query.all()
+        except SQLAlchemyError as excep:
+            self.logger.exception(excep)
+        return result
+
     def get_operations_in_group(self, operation_group_id, is_count=False,
                                 only_first_operation=False, only_gids=False):
         """
@@ -409,6 +423,14 @@ class OperationDAO(RootDAO):
     # ALGORITHM RELATED METHODS
     #
 
+    def get_all_algorithms(self):
+        try:
+            result = self.session.query(Algorithm).distinct().all()
+            return result
+        except SQLAlchemyError as ex:
+            self.logger.exception(ex)
+            return None
+
     def get_algorithm_by_id(self, algorithm_id):
         try:
             result = self.session.query(Algorithm).filter_by(id=algorithm_id).one()
