@@ -33,6 +33,8 @@ import os
 from datetime import datetime
 
 from tvb.adapters.datatypes.db.mapped_value import DatatypeMeasureIndex
+from tvb.adapters.datatypes.db.time_series import TimeSeriesIndex
+from tvb.adapters.datatypes.h5.time_series_h5 import TimeSeriesH5
 from tvb.basic.logger.builder import get_logger
 from tvb.config import MEASURE_METRICS_MODULE, MEASURE_METRICS_CLASS
 from tvb.core.entities.file.files_helper import FilesHelper
@@ -121,8 +123,8 @@ class BurstService(object):
         return operation
 
     @staticmethod
-    def get_burst_for_operation_id(operation_id):
-        return dao.get_burst_for_operation_id(operation_id)
+    def get_burst_for_operation_id(operation_id, is_group=False):
+        return dao.get_burst_for_operation_id(operation_id, is_group)
 
     def rename_burst(self, burst_id, new_name):
         """
@@ -198,16 +200,11 @@ class BurstService(object):
         return burst_config
 
     def prepare_burst_for_pse(self, burst_config):
-        # type: (BurstConfiguration) -> None
-        if burst_config.range2:
-            ranges = [burst_config.range1, burst_config.range2]
-        else:
-            ranges = [burst_config.range1]
-
-        operation_group = OperationGroup(burst_config.fk_project, ranges=ranges)
+        # type: (BurstConfiguration) -> (BurstConfiguration)
+        operation_group = OperationGroup(burst_config.fk_project, ranges=burst_config.ranges)
         operation_group = dao.store_entity(operation_group)
 
-        metric_operation_group = OperationGroup(burst_config.fk_project, ranges=ranges)
+        metric_operation_group = OperationGroup(burst_config.fk_project, ranges=burst_config.ranges)
         metric_operation_group = dao.store_entity(metric_operation_group)
 
         burst_config.operation_group = operation_group
@@ -244,10 +241,13 @@ class BurstService(object):
         self.logger.debug("Preparing indexes for simulation results in operation {}...".format(operation.id))
         for filename in result_filenames:
             index = h5.index_for_h5_file(filename)()
-            # TODO: don't load full TS in memory and make this read nicer
-            datatype, ga = h5.load_with_references(filename)
-            index.fill_from_has_traits(datatype)
-            index.fill_from_generic_attributes(ga)
+            h5_class = h5.REGISTRY.get_h5file_for_index(type(index))
+
+            with h5_class(filename) as ts_h5:
+                index.fill_from_h5(ts_h5)
+                index.fill_from_generic_attributes(ts_h5.load_generic_attributes())
+                index.gid = ts_h5.gid.load().hex
+
             index.fk_parent_burst = burst.gid
             index.fk_from_operation = operation.id
             if operation.fk_operation_group:
