@@ -37,33 +37,37 @@
 import json
 import os
 import shutil
+import uuid
 from cgi import FieldStorage
 from datetime import datetime
+
 from cherrypy._cpreqbody import Part
-from sqlalchemy.orm.attributes import manager_of_class
 from sqlalchemy.exc import IntegrityError, SQLAlchemyError
-from tvb.basic.profile import TvbProfile
+from sqlalchemy.orm.attributes import manager_of_class
 from tvb.basic.logger.builder import get_logger
+from tvb.basic.neotraits.ex import TraitTypeError
+from tvb.basic.profile import TvbProfile
 from tvb.config import VIEW_MODEL2ADAPTER, TVB_IMPORTER_MODULE, TVB_IMPORTER_CLASS
-from tvb.config.algorithm_categories import UploadAlgorithmCategoryConfig
+from tvb.config.algorithm_categories import UploadAlgorithmCategoryConfig, DEFAULTDATASTATE_INTERMEDIATE
 from tvb.core.adapters.abcadapter import ABCAdapter
-from tvb.core.entities.file.simulator.burst_configuration_h5 import BurstConfigurationH5
-from tvb.core.entities.model.model_datatype import DataTypeGroup
-from tvb.core.entities.model.model_operation import ResultFigure, Operation, STATUS_FINISHED
-from tvb.core.entities.model.model_project import Project
-from tvb.core.entities.storage import dao, transactional
-from tvb.core.entities.model.model_burst import BurstConfiguration
-from tvb.core.entities.file.xml_metadata_handlers import XMLReader
-from tvb.core.entities.file.files_helper import FilesHelper
-from tvb.core.entities.file.files_update_manager import FilesUpdateManager
 from tvb.core.entities.file.exceptions import FileStructureException, MissingDataSetException
 from tvb.core.entities.file.exceptions import IncompatibleFileManagerException
-from tvb.core.neotraits.db import HasTraitsIndex
-from tvb.core.services.exceptions import ImportException, ServicesBaseException
-from tvb.core.services.algorithm_service import AlgorithmService
-from tvb.core.project_versions.project_update_manager import ProjectUpdateManager
+from tvb.core.entities.file.files_helper import FilesHelper
+from tvb.core.entities.file.files_update_manager import FilesUpdateManager
+from tvb.core.entities.file.simulator.burst_configuration_h5 import BurstConfigurationH5
+from tvb.core.entities.file.xml_metadata_handlers import XMLReader
+from tvb.core.entities.model.model_burst import BurstConfiguration
+from tvb.core.entities.model.model_datatype import DataTypeGroup
+from tvb.core.entities.model.model_operation import ResultFigure, Operation, STATUS_FINISHED, STATUS_ERROR, \
+    OperationGroup
+from tvb.core.entities.model.model_project import Project
+from tvb.core.entities.storage import dao, transactional
 from tvb.core.neocom import h5
+from tvb.core.neotraits.db import HasTraitsIndex
 from tvb.core.neotraits.h5 import H5File, ViewModelH5
+from tvb.core.project_versions.project_update_manager import ProjectUpdateManager
+from tvb.core.services.algorithm_service import AlgorithmService
+from tvb.core.services.exceptions import ImportException, ServicesBaseException, MissingReferenceException
 
 OPERATION_XML = "Operation.xml"
 
@@ -102,6 +106,7 @@ class ImportService(object):
         self.user_id = None
         self.files_helper = FilesHelper()
         self.created_projects = []
+        self.view_model2adapter = self._populate_view_model2adapter()
 
     def _download_and_unpack_project_zip(self, uploaded, uq_file_name, temp_folder):
 
@@ -220,18 +225,50 @@ class ImportService(object):
                     self.logger.exception("Incompatibility details ...")
         return all_datatypes
 
+    @staticmethod
+    def check_import_references(file_path, datatype):
+        h5_class = H5File.h5_class_from_file(file_path)
+        reference_list = h5_class(file_path).gather_references()
+
+        for _, reference_gid in reference_list:
+            if not reference_gid:
+                continue
+
+            ref_index = dao.get_datatype_by_gid(reference_gid.hex)
+            if ref_index is None:
+                os.remove(file_path)
+                dao.remove_entity(datatype.__class__, datatype.id)
+                raise MissingReferenceException(
+                    'Imported file depends on datatypes that do not exist. Please upload '
+                    'those first!')
+
+    def _store_or_link_burst_config(self, burst_config, bc_path, project_id):
+        bc_already_in_tvb = dao.get_generic_entity(BurstConfiguration, burst_config.gid, 'gid')
+        if len(bc_already_in_tvb) == 0:
+            self.store_datatype(burst_config, bc_path)
+            return 1
+        return 0
+
+    def store_or_link_datatype(self, datatype, dt_path, project_id):
+        self.check_import_references(dt_path, datatype)
+        stored_dt_count = 0
+        datatype_already_in_tvb = dao.get_datatype_by_gid(datatype.gid)
+        if not datatype_already_in_tvb:
+            self.store_datatype(datatype, dt_path)
+            stored_dt_count = 1
+        elif datatype_already_in_tvb.parent_operation.project.id != project_id:
+            AlgorithmService.create_link([datatype_already_in_tvb.id], project_id)
+            if datatype_already_in_tvb.fk_datatype_group:
+                AlgorithmService.create_link([datatype_already_in_tvb.fk_datatype_group], project_id)
+        return stored_dt_count
+
     def _store_imported_datatypes_in_db(self, project, all_datatypes):
         # type: (Project, dict) -> int
         sorted_dts = sorted(all_datatypes.items(),
                             key=lambda dt_item: dt_item[1].create_date or datetime.now())
         count = 0
         for dt_path, datatype in sorted_dts:
-            datatype_already_in_tvb = dao.get_datatype_by_gid(datatype.gid)
-            if not datatype_already_in_tvb:
-                self.store_datatype(datatype, dt_path)
-                count += 1
-            else:
-                AlgorithmService.create_link([datatype_already_in_tvb.id], project.id)
+            count += self.store_or_link_datatype(datatype, dt_path, project.id)
         return count
 
     def _store_imported_images(self, project, temp_project_path, project_name):
@@ -245,18 +282,31 @@ class ImportService(object):
                 if metadata_file.endswith(FilesHelper.TVB_FILE_EXTENSION):
                     self._import_image(root, metadata_file, project.id, target_images_path)
 
-    def _retrieve_operations_in_order(self, project, import_path):
-        # type: (Project, str) -> list[Operation2ImportData]
+    @staticmethod
+    def _populate_view_model2adapter():
+        if len(VIEW_MODEL2ADAPTER) > 0:
+            return VIEW_MODEL2ADAPTER
+        view_model2adapter = {}
+        algos = dao.get_all_algorithms()
+        for algo in algos:
+            adapter = ABCAdapter.build_adapter(algo)
+            view_model_class = adapter.get_view_model_class()
+            view_model2adapter[view_model_class] = algo
+        return view_model2adapter
+
+    def _retrieve_operations_in_order(self, project, import_path, importer_operation_id=None):
+        # type: (Project, str, int) -> list[Operation2ImportData]
         retrieved_operations = []
 
         for root, _, files in os.walk(import_path):
             if OPERATION_XML in files:
                 # Previous Operation format for uploading previous versions of projects
                 operation_file_path = os.path.join(root, OPERATION_XML)
-                operation, operation_xml_parameters = self.__build_operation_from_file(project, operation_file_path)
+                operation, operation_xml_parameters, _ = self.build_operation_from_file(project, operation_file_path)
                 operation.import_file = operation_file_path
                 self.logger.debug("Found operation in old XML format: " + str(operation))
-                retrieved_operations.append(Operation2ImportData(operation, root, info_from_xml=operation_xml_parameters))
+                retrieved_operations.append(
+                    Operation2ImportData(operation, root, info_from_xml=operation_xml_parameters))
 
             else:
                 # We strive for the new format with ViewModelH5
@@ -272,7 +322,7 @@ class ImportService(object):
                                 all_view_model_files.append(h5_file)
                                 if not main_view_model:
                                     view_model = h5.load_view_model_from_file(h5_file)
-                                    if type(view_model) in VIEW_MODEL2ADAPTER.keys():
+                                    if type(view_model) in self.view_model2adapter.keys():
                                         main_view_model = view_model
                             else:
                                 file_update_manager = FilesUpdateManager()
@@ -282,12 +332,22 @@ class ImportService(object):
                             self.logger.warning("Unreadable H5 file will be ignored: %s" % h5_file)
 
                 if main_view_model is not None:
-                    alg = VIEW_MODEL2ADAPTER[type(main_view_model)]
+                    alg = self.view_model2adapter[type(main_view_model)]
+                    op_group_id = None
+                    if main_view_model.operation_group_gid:
+                        op_group = dao.get_operationgroup_by_gid(main_view_model.operation_group_gid.hex)
+                        if not op_group:
+                            op_group = OperationGroup(project.id, ranges=json.loads(main_view_model.ranges),
+                                                      gid=main_view_model.operation_group_gid.hex)
+                            op_group = dao.store_entity(op_group)
+                        op_group_id = op_group.id
                     operation = Operation(main_view_model.gid.hex, project.fk_admin, project.id, alg.id,
                                           status=STATUS_FINISHED,
                                           user_group=main_view_model.generic_attributes.operation_tag,
-                                          start_date=datetime.now(), completion_date=datetime.now())
+                                          start_date=datetime.now(), completion_date=datetime.now(),
+                                          op_group_id=op_group_id, range_values=main_view_model.range_values)
                     operation.create_date = main_view_model.create_date
+                    operation.visible = main_view_model.generic_attributes.visible
                     self.logger.debug("Found main ViewModel to create operation for it: " + str(operation))
 
                     retrieved_operations.append(
@@ -305,61 +365,127 @@ class ImportService(object):
                                           start_date=datetime.now(), completion_date=datetime.now())
                     self.logger.debug("Found no ViewModel in folder, so we default to " + str(operation))
 
+                    if importer_operation_id:
+                        operation.id = importer_operation_id
+
                     retrieved_operations.append(
                         Operation2ImportData(operation, root, view_model, dt_paths, all_view_model_files, True))
 
         return sorted(retrieved_operations, key=lambda op_data: op_data.order_field)
 
-    def import_project_operations(self, project, import_path):
+    def create_view_model(self, operation_entity, operation_data, new_op_folder, generic_attributes=None,
+                          add_params=None):
+        view_model = self._get_new_form_view_model(operation_entity, operation_data.info_from_xml)
+        if add_params is not None:
+            for element in add_params:
+                key_attr = getattr(view_model, element[0])
+                setattr(key_attr, element[1], element[2])
+
+        view_model.range_values = operation_entity.range_values
+        if operation_entity.operation_group:
+            view_model.operation_group_gid = uuid.UUID(operation_entity.operation_group.gid)
+            view_model.ranges = json.dumps(operation_entity.operation_group.range_references)
+            view_model.is_metric_operation = 'DatatypeMeasure' in operation_entity.operation_group.name
+
+        if generic_attributes is not None:
+            view_model.generic_attributes = generic_attributes
+        view_model.generic_attributes.operation_tag = operation_entity.user_group
+
+        h5.store_view_model(view_model, new_op_folder)
+        view_model_disk_size = FilesHelper.compute_recursive_h5_disk_usage(new_op_folder)
+        operation_entity.view_model_disk_size = view_model_disk_size
+        operation_entity.view_model_gid = view_model.gid.hex
+        dao.store_entity(operation_entity)
+        return view_model
+
+    def import_project_operations(self, project, import_path, is_group=False, importer_operation_id=None):
         """
         This method scans provided folder and identify all operations that needs to be imported
         """
+        all_dts_count = 0
+        all_stored_dts_count = 0
         imported_operations = []
-        ordered_operations = self._retrieve_operations_in_order(project, import_path)
+        ordered_operations = self._retrieve_operations_in_order(project, import_path, importer_operation_id)
 
         for operation_data in ordered_operations:
-            if operation_data.is_old_form:
-                operation_entity, datatype_group = self.__import_operation(operation_data.operation)
-                new_op_folder = self.files_helper.get_project_folder(project, str(operation_entity.id))
-                operation_datatypes = self._load_datatypes_from_operation_folder(operation_data.operation_folder,
-                                                                                 operation_entity, datatype_group)
-                # Create and store view_model from operation
-                view_model = self._get_new_form_view_model(operation_entity, operation_data.info_from_xml)
-                h5.store_view_model(view_model, new_op_folder)
-                operation_entity.view_model_gid = view_model.gid.hex
-                dao.store_entity(operation_entity)
 
-                self._store_imported_datatypes_in_db(project, operation_datatypes)
-                imported_operations.append(operation_entity)
+            if operation_data.is_old_form:
+                operation_entity, datatype_group = self.import_operation(operation_data.operation)
+                new_op_folder = self.files_helper.get_project_folder(project, str(operation_entity.id))
+
+                try:
+                    operation_datatypes = self._load_datatypes_from_operation_folder(operation_data.operation_folder,
+                                                                                     operation_entity, datatype_group)
+                    # Create and store view_model from operation
+                    self.create_view_model(operation_entity, operation_data, new_op_folder)
+
+                    self._store_imported_datatypes_in_db(project, operation_datatypes)
+                    imported_operations.append(operation_entity)
+                except MissingReferenceException:
+                    operation_entity.status = STATUS_ERROR
+                    dao.store_entity(operation_entity)
 
             elif operation_data.main_view_model is not None:
-                operation_entity = dao.store_entity(operation_data.operation)
-                dt_group = None  # TODO
+                do_merge = False
+                if importer_operation_id:
+                    do_merge = True
+                operation_entity = dao.store_entity(operation_data.operation, merge=do_merge)
+                dt_group = None
+                op_group = dao.get_operationgroup_by_id(operation_entity.fk_operation_group)
+                if op_group:
+                    dt_group = dao.get_datatypegroup_by_op_group_id(op_group.id)
+                    if not dt_group:
+                        first_op = dao.get_operations_in_group(op_group.id, only_first_operation=True)
+                        dt_group = DataTypeGroup(op_group, operation_id=first_op.id,
+                                                 state=DEFAULTDATASTATE_INTERMEDIATE)
+                        dt_group = dao.store_entity(dt_group)
                 # Store the DataTypes in db
                 dts = {}
+                all_dts_count += len(operation_data.dt_paths)
                 for dt_path in operation_data.dt_paths:
                     dt = self.load_datatype_from_file(dt_path, operation_entity.id, dt_group, project.id)
                     if isinstance(dt, BurstConfiguration):
-                        dao.store_entity(dt)
+                        if op_group:
+                            dt.fk_operation_group = op_group.id
+                        all_stored_dts_count += self._store_or_link_burst_config(dt, dt_path, project.id)
                     else:
                         dts[dt_path] = dt
-                stored_dts_count = self._store_imported_datatypes_in_db(project, dts)
+                        if op_group:
+                            op_group.fill_operationgroup_name(dt.type)
+                            dao.store_entity(op_group)
+                try:
+                    stored_dts_count = self._store_imported_datatypes_in_db(project, dts)
+                    all_stored_dts_count += stored_dts_count
 
-                if stored_dts_count > 0 or not operation_data.is_self_generated:
-                    imported_operations.append(operation_entity)
-                    new_op_folder = self.files_helper.get_project_folder(project, str(operation_entity.id))
-                    for h5_file in operation_data.all_view_model_files:
-                        shutil.move(h5_file, new_op_folder)
-                else:
-                    # In case all Dts under the current operation were Links and the ViewModel is dummy,
-                    # don't keep the Operation empty in DB
+                    if operation_data.main_view_model.is_metric_operation:
+                        self._update_burst_metric(operation_entity)
+
+                    #TODO: TVB-2849 to reveiw these flags and simplify condition
+                    if stored_dts_count > 0 or (not operation_data.is_self_generated and not is_group) or importer_operation_id is not None:
+                        imported_operations.append(operation_entity)
+                        new_op_folder = self.files_helper.get_project_folder(project, str(operation_entity.id))
+                        view_model_disk_size = 0
+                        for h5_file in operation_data.all_view_model_files:
+                            view_model_disk_size += FilesHelper.compute_size_on_disk(h5_file)
+                            shutil.move(h5_file, new_op_folder)
+                        operation_entity.view_model_disk_size = view_model_disk_size
+                        dao.store_entity(operation_entity)
+                    else:
+                        # In case all Dts under the current operation were Links and the ViewModel is dummy,
+                        # don't keep the Operation empty in DB
+                        dao.remove_entity(Operation, operation_entity.id)
+                        self.files_helper.remove_operation_data(project.name, operation_entity.id)
+                except MissingReferenceException as excep:
                     dao.remove_entity(Operation, operation_entity.id)
-
+                    self.files_helper.remove_operation_data(project.name, operation_entity.id)
+                    raise excep
             else:
                 self.logger.warning("Folder %s will be ignored, as we could not find a serialized "
                                     "operation or DTs inside!" % operation_data.operation_folder)
 
-        return imported_operations
+        self._update_dt_groups(project.id)
+        self._update_burst_configurations(project.id)
+        return imported_operations, all_dts_count, all_stored_dts_count
 
     @staticmethod
     def _get_new_form_view_model(operation, xml_parameters):
@@ -368,16 +494,20 @@ class ImportService(object):
         view_model = ad.get_view_model_class()()
 
         if xml_parameters:
-            params = json.loads(xml_parameters)
             declarative_attrs = type(view_model).declarative_attrs
 
-            for param in params:
+            if isinstance(xml_parameters, str):
+                xml_parameters = json.loads(xml_parameters)
+            for param in xml_parameters:
                 new_param_name = param
                 if param[0] == "_":
                     new_param_name = param[1:]
                 new_param_name = new_param_name.lower()
                 if new_param_name in declarative_attrs:
-                    setattr(view_model, new_param_name, params[param])
+                    try:
+                        setattr(view_model, new_param_name, xml_parameters[param])
+                    except TraitTypeError:
+                        pass
         return view_model
 
     def _import_image(self, src_folder, metadata_file, project_id, target_images_path):
@@ -409,6 +539,7 @@ class ImportService(object):
         """
         self.logger.debug("Loading DataType from file: %s" % current_file)
         h5_class = H5File.h5_class_from_file(current_file)
+
         if h5_class is BurstConfigurationH5:
             if current_project_id is None:
                 op_entity = dao.get_operationgroup_by_id(op_id)
@@ -416,8 +547,6 @@ class ImportService(object):
             h5_file = BurstConfigurationH5(current_file)
             burst = BurstConfiguration(current_project_id)
             burst.fk_simulation = op_id
-            # burst.fk_operation_group = TODO
-            # burst.fk_metric_operation_group = TODO
             h5_file.load_into(burst)
             result = burst
         else:
@@ -428,8 +557,11 @@ class ImportService(object):
             datatype_index.fill_from_generic_attributes(generic_attributes)
 
             # Add all the required attributes
-            if datatype_group is not None:
+            if datatype_group:
                 datatype_index.fk_datatype_group = datatype_group.id
+                if len(datatype_group.subject) == 0:
+                    datatype_group.subject = datatype_index.subject
+                    dao.store_entity(datatype_group)
             datatype_index.fk_from_operation = op_id
 
             associated_file = h5.path_for_stored_index(datatype_index)
@@ -448,8 +580,11 @@ class ImportService(object):
                 final_path = h5.path_for_stored_index(datatype)
                 if final_path != current_file:
                     shutil.move(current_file, final_path)
+            stored_entry = dao.get_datatype_by_gid(datatype.gid)
+            if not stored_entry:
+                stored_entry = dao.store_entity(datatype)
 
-            return dao.store_entity(datatype)
+            return stored_entry
         except MissingDataSetException as e:
             self.logger.exception(e)
             error_msg = "Datatype %s has missing data and could not be imported properly." % (datatype,)
@@ -479,7 +614,7 @@ class ImportService(object):
                          "project with the same name or gid.") % (project_entity.name, project_entity.gid)
             raise ImportException(error_msg)
 
-    def __build_operation_from_file(self, project, operation_file):
+    def build_operation_from_file(self, project, operation_file):
         """
         Create Operation entity from metadata file.
         """
@@ -488,7 +623,7 @@ class ImportService(object):
         return operation_entity.from_dict(operation_dict, dao, self.user_id, project.gid)
 
     @staticmethod
-    def __import_operation(operation_entity):
+    def import_operation(operation_entity, migration=False):
         """
         Store a Operation entity.
         """
@@ -501,10 +636,11 @@ class ImportService(object):
                 datatype_group = dao.get_datatypegroup_by_op_group_id(operation_group_id)
             except SQLAlchemyError:
                 # If no dataType group present for current op. group, create it.
-                operation_group = dao.get_operationgroup_by_id(operation_group_id)
-                datatype_group = DataTypeGroup(operation_group, operation_id=operation_entity.id)
-                datatype_group.state = UploadAlgorithmCategoryConfig.defaultdatastate
-                datatype_group = dao.store_entity(datatype_group)
+                if migration is False:
+                    operation_group = dao.get_operationgroup_by_id(operation_group_id)
+                    datatype_group = DataTypeGroup(operation_group, operation_id=operation_entity.id)
+                    datatype_group.state = UploadAlgorithmCategoryConfig.defaultdatastate
+                    datatype_group = dao.store_entity(datatype_group)
 
         return operation_entity, datatype_group
 
@@ -527,3 +663,25 @@ class ImportService(object):
             return temp_folder
         except FileStructureException as excep:
             raise ServicesBaseException("Could not process the given ZIP file..." + str(excep))
+
+    def _update_burst_metric(self, operation_entity):
+        burst_config = dao.get_burst_for_operation_id(operation_entity.id)
+        if burst_config and burst_config.ranges:
+            if burst_config.fk_metric_operation_group is None:
+                burst_config.fk_metric_operation_group = operation_entity.fk_operation_group
+            dao.store_entity(burst_config)
+
+    def _update_dt_groups(self, project_id):
+        dt_groups = dao.get_datatypegroup_for_project(project_id)
+        for dt_group in dt_groups:
+            dt_group.count_results = dao.count_datatypes_in_group(dt_group.id)
+            dts_in_group = dao.get_datatypes_from_datatype_group(dt_group.id)
+            if dts_in_group:
+                dt_group.fk_parent_burst = dts_in_group[0].fk_parent_burst
+            dao.store_entity(dt_group)
+
+    def _update_burst_configurations(self, project_id):
+        burst_configs = dao.get_bursts_for_project(project_id)
+        for burst_config in burst_configs:
+            burst_config.datatypes_number = dao.count_datatypes_in_burst(burst_config.gid)
+            dao.store_entity(burst_config)
