@@ -43,11 +43,13 @@ import sys
 import uuid
 import zipfile
 from copy import copy
+from inspect import isclass
+
 from tvb.basic.exceptions import TVBException
 from tvb.basic.logger.builder import get_logger
 from tvb.basic.neotraits.api import Range
 from tvb.basic.profile import TvbProfile
-from tvb.config import choices, MEASURE_METRICS_MODULE, MEASURE_METRICS_CLASS, MEASURE_METRICS_MODEL_CLASS
+from tvb.config import MEASURE_METRICS_MODULE, MEASURE_METRICS_CLASS, MEASURE_METRICS_MODEL_CLASS, ALGORITHMS
 from tvb.core.adapters import constants
 from tvb.core.adapters.abcadapter import ABCAdapter, AdapterLaunchModeEnum
 from tvb.core.adapters.exceptions import LaunchException
@@ -61,6 +63,7 @@ from tvb.core.entities.model.model_operation import STATUS_FINISHED, STATUS_ERRO
 from tvb.core.entities.storage import dao, transactional
 from tvb.core.entities.transient.structure_entities import DataTypeMetaData
 from tvb.core.neocom import h5
+from tvb.core.neotraits.h5 import ViewModelH5
 from tvb.core.services.backend_client_factory import BackendClientFactory
 from tvb.core.services.burst_service import BurstService
 from tvb.core.services.exceptions import OperationException
@@ -92,8 +95,8 @@ class OperationService:
         Gets the parameters of the computation from the previous inputs form,
         and launches a computation (on the cluster or locally).
         
-        Invoke custom method on an Adapter Instance. Make sure when the  
-        operation has finished that the correct results are stored into DB. 
+        Invoke custom method on an Adapter Instance. Make sure when the
+        operation has finished that the correct results are stored into DB.
         """
         if not isinstance(adapter_instance, ABCAdapter):
             self.logger.warning("Inconsistent Adapter Class:" + str(adapter_instance.__class__))
@@ -117,7 +120,8 @@ class OperationService:
             return self._send_to_cluster(operations, adapter_instance, current_user.username)
 
     @staticmethod
-    def _prepare_metadata(algo_category, submit_data, operation_group=None, burst=None):
+    def _prepare_metadata(algo_category, submit_data, operation_group=None, burst=None,
+                          current_ga=GenericAttributes()):
         """
         Gather generic_metadata from submitted fields and current to be execute algorithm.
         Will populate STATE, GROUP, etc in generic_metadata
@@ -129,8 +133,7 @@ class OperationService:
             generic_metadata.operation_tag = submit_data[DataTypeMetaData.KEY_OPERATION_TAG]
         if DataTypeMetaData.KEY_TAG_1 in submit_data:
             generic_metadata.user_tag_1 = submit_data[DataTypeMetaData.KEY_TAG_1]
-        if operation_group is not None:
-            generic_metadata.user_tag_3 = operation_group.name
+        generic_metadata.fill_from(current_ga)
         return generic_metadata
 
     @staticmethod
@@ -167,15 +170,20 @@ class OperationService:
 
         view_model = get_class_by_name("{}.{}".format(MEASURE_METRICS_MODULE, MEASURE_METRICS_MODEL_CLASS))()
         view_model.time_series = time_series_index.gid
-        view_model.algorithms = tuple(choices.values())
+        view_model.algorithms = tuple(ALGORITHMS.keys())
         view_model.generic_attributes = ga
 
         parent_burst = dao.get_generic_entity(BurstConfiguration, time_series_index.fk_parent_burst, 'gid')[0]
+        metric_op_group = dao.get_operationgroup_by_id(parent_burst.fk_metric_operation_group)
         metric_operation_group_id = parent_burst.fk_metric_operation_group
         range_values = sim_operation.range_values
-        metric_operation = Operation(view_model.gid.hex, sim_operation.fk_launched_by, sim_operation.fk_launched_in, metric_algo.id,
-                                     user_group=ga.operation_tag,
-                                     op_group_id=metric_operation_group_id, range_values=range_values)
+        view_model.operation_group_gid = uuid.UUID(metric_op_group.gid)
+        view_model.ranges = json.dumps(parent_burst.ranges)
+        view_model.range_values = range_values
+        view_model.is_metric_operation = True
+        metric_operation = Operation(view_model.gid.hex, sim_operation.fk_launched_by, sim_operation.fk_launched_in,
+                                     metric_algo.id, user_group=ga.operation_tag, op_group_id=metric_operation_group_id,
+                                     range_values=range_values)
         metric_operation.visible = False
         metric_operation = dao.store_entity(metric_operation)
 
@@ -183,8 +191,9 @@ class OperationService:
                                                         'fk_operation_group')[0]
         if metrics_datatype_group.fk_from_operation is None:
             metrics_datatype_group.fk_from_operation = metric_operation.id
+            dao.store_entity(metrics_datatype_group)
 
-        self._store_view_model(metric_operation, sim_operation.project, view_model)
+        self.store_view_model(metric_operation, sim_operation.project, view_model)
         return metric_operation
 
     @transactional
@@ -209,7 +218,7 @@ class OperationService:
     def prepare_operations(self, user_id, project, algorithm, category,
                            visible=True, existing_dt_group=None, view_model=None, **kwargs):
         """
-        Do all the necessary preparations for storing an operation. If it's the case of a 
+        Do all the necessary preparations for storing an operation. If it's the case of a
         range of values create an operation group and multiple operations for each possible
         instance from the range.
         """
@@ -224,7 +233,7 @@ class OperationService:
         group_id = None
         if group is not None:
             group_id = group.id
-        ga = self._prepare_metadata(category, kwargs, group)
+        ga = self._prepare_metadata(category, kwargs, group, current_ga=view_model.generic_attributes)
         ga.visible = visible
         view_model.generic_attributes = ga
 
@@ -249,14 +258,16 @@ class OperationService:
                 dao.store_entity(existing_dt_group)
 
         for operation in operations:
-            self._store_view_model(operation, project, view_model)
+            self.store_view_model(operation, project, view_model)
 
         return operations, group
 
-    @staticmethod
-    def _store_view_model(operation, project, view_model):
+    def store_view_model(self, operation, project, view_model):
         storage_path = FilesHelper().get_project_folder(project, str(operation.id))
         h5.store_view_model(view_model, storage_path)
+        view_model_size_on_disk = FilesHelper.compute_recursive_h5_disk_usage(storage_path)
+        operation.view_model_disk_size = view_model_size_on_disk
+        dao.store_entity(operation)
 
     def initiate_prelaunch(self, operation, adapter_instance, **kwargs):
         """
@@ -278,17 +289,27 @@ class OperationService:
             available_space = disk_space_per_user - pending_op_disk_space - user_disk_space
 
             view_model = adapter_instance.load_view_model(operation)
+            try:
+                form = adapter_instance.get_form()
+                form = form() if isclass(form) else form
+                fields = form.get_upload_field_names()
+                project = dao.get_project_by_id(operation.fk_launched_in)
+                tmp_folder = self.file_helper.get_project_folder(project, self.file_helper.TEMP_FOLDER)
+                for upload_field in fields:
+                    if hasattr(view_model, upload_field):
+                        file = getattr(view_model, upload_field)
+                        if file.startswith(tmp_folder):
+                            temp_files.append(file)
+            except AttributeError:
+                # Skip if we don't have upload fields on current form
+                pass
             result_msg, nr_datatypes = adapter_instance._prelaunch(operation, view_model, unique_id, available_space)
             operation = dao.get_operation_by_id(operation.id)
             # Update DB stored kwargs for search purposes, to contain only valuable params (no unselected options)
             operation.mark_complete(STATUS_FINISHED)
             dao.store_entity(operation)
-            adapter_form = adapter_instance.get_form()
-            try:
-                temp_files = adapter_form.temporary_files
-            except AttributeError:
-                pass
 
+            self._update_vm_generic_operation_tag(view_model, operation)
             self._remove_files(temp_files)
 
         except zipfile.BadZipfile as excep:
@@ -321,6 +342,14 @@ class OperationService:
 
         return operations
 
+    @staticmethod
+    def _update_vm_generic_operation_tag(view_model, operation):
+        project = dao.get_project_by_id(operation.fk_launched_in)
+        storage_path = FilesHelper().get_project_folder(project, str(operation.id))
+        h5_path = h5.path_for(storage_path, ViewModelH5, view_model.gid, type(view_model).__name__)
+        with ViewModelH5(h5_path, view_model) as vm_h5:
+            vm_h5.operation_tag.store(operation.user_group)
+
     def launch_operation(self, operation_id, send_to_cluster=False, adapter_instance=None):
         """
         Method exposed for Burst-Workflow related calls.
@@ -358,15 +387,16 @@ class OperationService:
         Currently used to delete temporary files created during an operation.
         """
         for pth in file_list:
-            pth = str(pth)
-            try:
-                if os.path.exists(pth) and os.path.isfile(pth):
-                    os.remove(pth)
-                    self.logger.debug("We no longer need file:" + pth + " => deleted")
-                else:
-                    self.logger.warning("Trying to remove not existent file:" + pth)
-            except OSError:
-                self.logger.exception("Could not cleanup file!")
+            if pth is not None:
+                pth = str(pth)
+                try:
+                    if os.path.exists(pth) and os.path.isfile(pth):
+                        os.remove(pth)
+                        self.logger.debug("We no longer need file:" + pth + " => deleted")
+                    else:
+                        self.logger.warning("Trying to remove not existent file:" + pth)
+                except OSError:
+                    self.logger.exception("Could not cleanup file!")
 
     @staticmethod
     def _range_name(range_no):
@@ -516,7 +546,7 @@ class OperationService:
         else:
             result = BackendClientFactory.stop_operation(operation_id)
             if remove_after_stop:
-                burst_config = dao.get_burst_for_operation_id(operation_id)
+                burst_config = dao.get_burst_for_direct_operation_id(operation_id)
                 ProjectService().remove_operation(operation_id)
                 if burst_config is not None:
                     result = dao.remove_entity(BurstConfiguration, burst_config.id) or result
