@@ -40,6 +40,7 @@ from tvb.basic.logger.builder import get_logger
 from tvb.core.adapters.abcadapter import ABCAdapter
 from tvb.core.adapters.inputs_processor import review_operation_inputs_from_adapter
 from tvb.core.entities.load import load_entity_by_gid
+from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.model.model_datatype import Links, DataType, DataTypeGroup
 from tvb.core.entities.model.model_operation import Operation, OperationGroup
 from tvb.core.entities.model.model_project import Project
@@ -295,17 +296,17 @@ class ProjectService:
             project2delete = dao.get_project_by_id(project_id)
 
             self.logger.debug("Deleting project: id=" + str(project_id) + ' name=' + project2delete.name)
-            project_bursts = dao.get_bursts_for_project(project_id)
-            for burst in project_bursts:
-                dao.remove_entity(burst.__class__, burst.id)
-
             project_datatypes = dao.get_datatypes_in_project(project_id)
+            project_datatypes.sort(key=lambda dt: dt.create_date, reverse=True)
             for one_data in project_datatypes:
                 self.remove_datatype(project_id, one_data.gid, True)
 
             links = dao.get_links_for_project(project_id)
             for one_link in links:
                 dao.remove_entity(Links, one_link.id)
+            project_bursts = dao.get_bursts_for_project(project_id)
+            for burst in project_bursts:
+                dao.remove_entity(burst.__class__, burst.id)
 
             self.structure_helper.remove_project_structure(project2delete.name)
             dao.delete_project(project_id)
@@ -618,26 +619,37 @@ class ProjectService:
             return
 
         is_datatype_group = False
+        datatype_group = None
         if dao.is_datatype_group(datatype_gid):
             is_datatype_group = True
+            datatype_group = datatype
         elif datatype.fk_datatype_group is not None:
             is_datatype_group = True
-            datatype = dao.get_datatype_by_id(datatype.fk_datatype_group)
+            datatype_group = dao.get_datatype_by_id(datatype.fk_datatype_group)
 
         operations_set = [datatype.fk_from_operation]
         correct = True
 
         if is_datatype_group:
-            self.logger.debug("Removing datatype group %s" % datatype)
-            data_list = dao.get_datatypes_from_datatype_group(datatype.id)
-            for adata in data_list:
-                self._remove_project_node_files(project_id, adata.gid, skip_validation)
-                if adata.fk_from_operation not in operations_set:
-                    operations_set.append(adata.fk_from_operation)
+            operations_set = [datatype_group.fk_from_operation]
+            self.logger.debug("Removing datatype group %s" % datatype_group)
+            if datatype_group.fk_parent_burst:
+                burst = dao.get_generic_entity(BurstConfiguration, datatype_group.fk_parent_burst, 'gid')[0]
+                dao.remove_entity(BurstConfiguration, burst.id)
+                if burst.fk_metric_operation_group:
+                    correct = correct and self._remove_operation_group(burst.fk_metric_operation_group, project_id,
+                                                                       skip_validation, operations_set)
 
-            datatype_group = dao.get_datatype_group_by_gid(datatype.gid)
-            dao.remove_entity(DataTypeGroup, datatype.id)
-            correct = correct and dao.remove_entity(OperationGroup, datatype_group.fk_operation_group)
+                if burst.fk_operation_group:
+                    correct = correct and self._remove_operation_group(burst.fk_operation_group, project_id,
+                                                                       skip_validation, operations_set)
+
+            else:
+                self._remove_datatype_group_dts(project_id, datatype_group.id, skip_validation, operations_set)
+
+                datatype_group = dao.get_datatype_group_by_gid(datatype_group.gid)
+                dao.remove_entity(DataTypeGroup, datatype.id)
+                correct = correct and dao.remove_entity(OperationGroup, datatype_group.fk_operation_group)
         else:
             self.logger.debug("Removing datatype %s" % datatype)
             self._remove_project_node_files(project_id, datatype.gid, skip_validation)
@@ -649,13 +661,33 @@ class ProjectService:
             if len(dependent_dt) > 0:
                 # Do not remove Operation in case DataType still exist referring it.
                 continue
+            op_burst = dao.get_burst_for_operation_id(operation_id)
+            if op_burst:
+                correct = correct and dao.remove_entity(BurstConfiguration, op_burst.id)
             correct = correct and dao.remove_entity(Operation, operation_id)
             # Make sure Operation folder is removed
-            self.structure_helper.remove_operation_data(project.name, datatype.fk_from_operation)
+            self.structure_helper.remove_operation_data(project.name, operation_id)
 
         if not correct:
             raise RemoveDataTypeException("Could not remove DataType " + str(datatype_gid))
 
+    def _remove_operation_group(self, operation_group_id, project_id, skip_validation, operations_set):
+        metrics_groups = dao.get_generic_entity(DataTypeGroup, operation_group_id,
+                                                'fk_operation_group')
+        if len(metrics_groups) > 0:
+            metric_datatype_group_id = metrics_groups[0].id
+            self._remove_datatype_group_dts(project_id, metric_datatype_group_id, skip_validation,
+                                            operations_set)
+            dao.remove_entity(DataTypeGroup, metric_datatype_group_id)
+        return dao.remove_entity(OperationGroup, operation_group_id)
+
+    def _remove_datatype_group_dts(self, project_id, dt_group_id, skip_validation, operations_set):
+        data_list = dao.get_datatypes_from_datatype_group(dt_group_id)
+        for adata in data_list:
+            self._remove_project_node_files(project_id, adata.gid, skip_validation)
+            if adata.fk_from_operation not in operations_set:
+                operations_set.append(adata.fk_from_operation)
+
     def update_metadata(self, submit_data):
         """
         Update DataType/ DataTypeGroup metadata
