@@ -35,16 +35,14 @@ Launch an operation from the command line
 """
 
 if __name__ == "__main__":
-    from tvb.basic.profile import TvbProfile
-    TvbProfile.set_profile(TvbProfile.COMMAND_PROFILE)
+    from tvb.interfaces.command.lab import *
 
+from tvb.adapters.uploaders.tvb_importer import TVBImporter, TVBImporterModel
 from tvb.core.adapters.abcadapter import ABCAdapter
 from tvb.core.entities.storage import dao
 from tvb.core.services.operation_service import OperationService
-from tvb.adapters.uploaders.tvb_importer import TVBImporter
 
 
-# Before starting this, we need to have TVB web interface launched at least once (to have a default project, user, etc)
 def import_h5(file_path, project_id):
     service = OperationService()
 
@@ -53,14 +51,14 @@ def import_h5(file_path, project_id):
 
     adapter_instance = ABCAdapter.build_adapter_from_class(TVBImporter)
 
-    # Prepare the input algorithms as if they were coming from web UI submit:
-    launch_args = {"data_file": file_path}
+    view_model = TVBImporterModel()
+    view_model.data_file = file_path
 
     print("We will try to import file at path " + file_path)
     # launch an operation and have the results stored both in DB and on disk
-    launched_operations = service.fire_operation(adapter_instance,
-                                                 project.administrator,
-                                                 project.id,
-                                                 **launch_args)
+    service.fire_operation(adapter_instance,
+                           project.administrator,
+                           project.id,
+                           view_model=view_model)
 
     print("Operation launched. Check the web UI")
