@@ -33,28 +33,25 @@ Find a Connectivity in current project (by Subject) and later run a simulation o
 
 __main__ will contain the code.
 """
-
-import numpy
 from time import sleep
 from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
 from tvb.adapters.datatypes.db.time_series import TimeSeriesRegionIndex
-from tvb.basic.profile import TvbProfile
 from tvb.basic.logger.builder import get_logger
-from tvb.config.init.introspector_registry import IntrospectionRegistry
-from tvb.core.entities.model.model_operation import STATUS_FINISHED
+from tvb.core.entities.transient.structure_entities import DataTypeMetaData
+from tvb.simulator.coupling import Scaling
+from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
 from tvb.core.services.algorithm_service import AlgorithmService
 from tvb.core.entities.model.model_burst import BurstConfiguration
-from tvb.core.entities.storage import dao
-from tvb.core.entities.transient.structure_entities import DataTypeMetaData
+from tvb.config.init.introspector_registry import IntrospectionRegistry
+from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel
 from tvb.core.services.simulator_service import SimulatorService
-from tvb.simulator.simulator import Simulator
-from tvb.simulator.coupling import Scaling
 
 # Before starting this, we need to have TVB web interface launched at least once
 # (to have a default project, user and connectivity)
-if __name__ == "__main__":
-    TvbProfile.set_profile(TvbProfile.COMMAND_PROFILE)
+def run_simulation():
+    from tvb.interfaces.command.lab import *
+
     log = get_logger(__name__)
 
     # This ID of a project needs to exists in DB, and it can be taken from the WebInterface:
@@ -64,25 +61,24 @@ if __name__ == "__main__":
     connectivity_index = dao.get_generic_entity(ConnectivityIndex, DataTypeMetaData.DEFAULT_SUBJECT, "subject")[0]
     connectivity = h5.load_from_index(connectivity_index)
 
-    # Prepare a Simulator instance with defaults and configure it to use the previously loaded Connectivity
-    simulator = Simulator()
-    simulator.connectivity = connectivity
-    # Configure the Simulator to use a Scaling type coupling
-    simulator.coupling = Scaling()
-    # Choose a higher value for the 'tau' parameter of the Generic2dOscillator model
-    simulator.model.tau = numpy.array([2.0])
-    # Configure the simulation length
-    simulator.simulation_length = 100
-
     # Load the SimulatorAdapter algorithm from DB
-    cached_simulator_algorithm = AlgorithmService().get_algorithm_by_module_and_class(IntrospectionRegistry.SIMULATOR_MODULE,
-                                                                                      IntrospectionRegistry.SIMULATOR_CLASS)
+    cached_simulator_algorithm = AlgorithmService().get_algorithm_by_module_and_class(
+        IntrospectionRegistry.SIMULATOR_MODULE,
+        IntrospectionRegistry.SIMULATOR_CLASS)
 
     # Instantiate a SimulatorService and launch the configured simulation
+    simulator_model = SimulatorAdapterModel()
+    simulator_model.connectivity = connectivity.gid
+    simulator_model.simulation_length = 100
+    simulator_model.coupling = Scaling()
+
     simulator_service = SimulatorService()
-    launched_operation = simulator_service.async_launch_and_prepare_simulation(BurstConfiguration(project.id),
+    burst = BurstConfiguration(project.id, name="Simulation")
+    dao.store_entity(burst)
+    launched_operation = simulator_service.async_launch_and_prepare_simulation(burst,
                                                                                project.administrator, project,
-                                                                               cached_simulator_algorithm, simulator)
+                                                                               cached_simulator_algorithm,
+                                                                               simulator_model)
 
     # wait for the operation to finish
     while not launched_operation.has_finished:
@@ -95,3 +91,7 @@ if __name__ == "__main__":
     else:
         log.warning("Operation ended with problems [%s]: [%s]" % (launched_operation.status,
                                                                   launched_operation.additional_info))
+
+
+if __name__ == "__main__":
+    run_simulation()
