@@ -87,6 +87,7 @@ KEY_LAST_LOADED_FORM_URL = 'last_loaded_form_url'
 KEY_BACK_PAGE = "back_page_link"
 KEY_SECTION_TITLES = "section_titles"
 KEY_SUBSECTION_TITLES = "sub_section_titles"
+KEY_IS_SIMULATOR_BRANCH = "is_branch"
 
 # Overlay specific keys
 KEY_OVERLAY_TITLE = "overlay_title"
@@ -212,6 +213,7 @@ def clean_project_data_from_session():
     remove_from_session(KEY_SIMULATOR_CONFIG)
     remove_from_session(KEY_LAST_LOADED_FORM_URL)
     remove_from_session(KEY_BURST_CONFIG)
+    remove_from_session(KEY_IS_SIMULATOR_BRANCH)
     add2session(KEY_IS_SIMULATOR_LOAD, False)
 
 
