@@ -35,13 +35,13 @@ given action are described here.
 .. moduleauthor:: Lia Domide <lia.domide@codemart.ro>
 """
 
-import copy
 import json
+import sys
+
 import cherrypy
 import formencode
 import numpy
 import six
-import sys
 from tvb.basic.neotraits.ex import TraitValueError
 from tvb.core.adapters import constants
 from tvb.core.adapters.abcadapter import ABCAdapter
@@ -52,7 +52,7 @@ from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.entities.load import load_entity_by_gid
 from tvb.core.neocom import h5
 from tvb.core.neocom.h5 import REGISTRY
-from tvb.core.neotraits.forms import Form, TraitDataTypeSelectField
+from tvb.core.neotraits.forms import TraitDataTypeSelectField
 from tvb.core.neotraits.view_model import DataTypeGidAttr
 from tvb.core.services.exceptions import OperationException
 from tvb.core.services.operation_service import OperationService, RANGE_PARAMETER_1, RANGE_PARAMETER_2
@@ -62,8 +62,8 @@ from tvb.interfaces.web.controllers import common
 from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.common import InvalidFormValues
-from tvb.interfaces.web.controllers.decorators import expose_page, settings, context_selected, expose_numpy_array
 from tvb.interfaces.web.controllers.decorators import expose_fragment, handle_error, check_user, expose_json
+from tvb.interfaces.web.controllers.decorators import expose_page, settings, context_selected, expose_numpy_array
 from tvb.interfaces.web.controllers.simulator_controller import SimulatorController
 from tvb.interfaces.web.entities.context_selected_adapter import SelectedAdapterContext
 
@@ -91,6 +91,24 @@ class FlowController(BaseController):
         self.context = SelectedAdapterContext()
         self.files_helper = FilesHelper()
         self.operation_services = OperationService()
+        self.simulator_controller = SimulatorController()
+
+        analyze_category, groups = self.algorithm_service.get_analyze_groups()
+        adapters_list = []
+        for adapter_group in groups:
+
+            if len(adapter_group.children) > 1:
+                ids = [str(child.id) for child in adapter_group.children]
+                ids = ','.join(ids)
+                adapter_link = '/flow/show_group_of_algorithms/' + str(analyze_category.id) + "/" + ids
+            else:
+                adapter_link = self.get_url_adapter(analyze_category.id, adapter_group.children[0].id)
+
+            adapters_list.append({common.KEY_TITLE: adapter_group.name,
+                                  'link': adapter_link,
+                                  'description': adapter_group.description,
+                                  'subsection': adapter_group.children[0].subsection_name})
+        self.analyze_adapters = adapters_list
 
     @expose_page
     @settings
@@ -104,22 +122,7 @@ class FlowController(BaseController):
             step_name = analyze_category.displayname.lower()
             template_specification = dict(mainContent="header_menu", section_name=step_name, controlPage=None,
                                           title="Select an analyzer", displayControl=False)
-            adapters_list = []
-            for adapter_group in groups:
-
-                if len(adapter_group.children) > 1:
-                    ids = [str(child.id) for child in adapter_group.children]
-                    ids = ','.join(ids)
-                    adapter_link = '/flow/show_group_of_algorithms/' + str(analyze_category.id) + "/" + ids
-                else:
-                    adapter_link = self.get_url_adapter(analyze_category.id, adapter_group.children[0].id)
-
-                adapters_list.append({common.KEY_TITLE: adapter_group.name,
-                                      'link': adapter_link,
-                                      'description': adapter_group.description,
-                                      'subsection': adapter_group.children[0].subsection_name})
-            self.analyze_adapters = adapters_list
-            template_specification[common.KEY_SUBMENU_LIST] = adapters_list
+            template_specification[common.KEY_SUBMENU_LIST] = self.analyze_adapters
             return self.fill_default_attributes(template_specification)
 
         except ValueError:
@@ -169,7 +172,8 @@ class FlowController(BaseController):
             algorithm = self.algorithm_service.get_algorithm_by_identifier(algorithm_id)
             algorithm.link = self.get_url_adapter(step_key, algorithm_id)
             adapter_instance = self.algorithm_service.prepare_adapter(algorithm)
-            adapter_form = self.algorithm_service.prepare_adapter_form(adapter_instance, project.id)
+            adapter_form = self.algorithm_service.prepare_adapter_form(adapter_instance=adapter_instance,
+                                                                       project_id=project.id)
             algorithm.form = self.render_adapter_form(adapter_form)
             algorithms.append(algorithm)
 
@@ -269,12 +273,12 @@ class FlowController(BaseController):
         filter = FilterChain(fields=fields, operations=operations, values=values)
         project = common.get_current_project()
 
-        form = Form(project_id=project.id, draw_ranges=True)
         data_type_gid_attr = DataTypeGidAttr(linked_datatype=REGISTRY.get_datatype_for_index(index_class))
         data_type_gid_attr.required = not string2bool(has_none_option)
 
-        select_field = TraitDataTypeSelectField(data_type_gid_attr, form, conditions=filter,
+        select_field = TraitDataTypeSelectField(data_type_gid_attr, conditions=filter,
                                                 has_all_option=string2bool(has_all_option))
+        self.algorithm_service.fill_selectfield_with_datatypes(select_field, project.id)
 
         return {'options': select_field.options()}
 
@@ -284,11 +288,7 @@ class FlowController(BaseController):
         adapter_instance = ABCAdapter.build_adapter(algorithm)
 
         try:
-            form = adapter_instance.get_form()(project_id=project_id)
-            if 'fill_defaults' in data:
-                form.fill_from_post_plus_defaults(data)
-            else:
-                form.fill_from_post(data)
+            form = self.algorithm_service.fill_adapter_form(adapter_instance, data, project_id)
             view_model = None
             if form.validate():
                 try:
@@ -303,6 +303,7 @@ class FlowController(BaseController):
                 raise InvalidFormValues("Invalid form inputs! Could not fill algorithm from the given inputs!",
                                         error_dict=form.get_errors_dict())
 
+
             adapter_instance.submit_form(form)
 
             if issubclass(type(adapter_instance), ABCDisplayer):
@@ -316,7 +317,7 @@ class FlowController(BaseController):
                 return {}
 
             result = self.operation_services.fire_operation(adapter_instance, common.get_logged_user(),
-                                                            project_id, view_model=view_model)
+                                                        project_id, view_model=view_model)
             if isinstance(result, list):
                 result = "Launched %s operations." % len(result)
             common.set_important_message(str(result))
@@ -338,7 +339,8 @@ class FlowController(BaseController):
             template_specification[common.KEY_ERRORS] = errors
         return template_specification
 
-    def get_template_for_adapter(self, project_id, step_key, stored_adapter, submit_url, is_burst=True):
+    def get_template_for_adapter(self, project_id, step_key, stored_adapter, submit_url, is_burst=True,
+                                 is_callout=False):
         """ Get Input HTML Interface template or a given adapter """
         try:
             group = None
@@ -349,13 +351,15 @@ class FlowController(BaseController):
 
             adapter_instance = self.algorithm_service.prepare_adapter(stored_adapter)
 
-            adapter_form = self.algorithm_service.prepare_adapter_form(adapter_instance, project_id)
+            adapter_form = self.algorithm_service.prepare_adapter_form(adapter_instance=adapter_instance,
+                                                                       project_id=project_id)
             vm = self.context.get_view_model_from_session()
             if vm and type(vm) == adapter_form.get_view_model():
                 adapter_form.fill_from_trait(vm)
             else:
                 self.context.clean_from_session()
-            template_specification = dict(submitLink=submit_url, adapter_form=self.render_adapter_form(adapter_form),
+            template_specification = dict(submitLink=submit_url,
+                                          adapter_form=self.render_adapter_form(adapter_form, is_callout=is_callout),
                                           title=title)
 
             self._populate_section(stored_adapter, template_specification, is_burst)
@@ -481,11 +485,11 @@ class FlowController(BaseController):
         AJAX exposed method. Will return only a piece of a page,
         to be integrated as part in another page.
         """
-        template_specification = self.get_adapter_template(project_id, algorithm_id, False, back_page)
+        template_specification = self.get_adapter_template(project_id, algorithm_id, False, back_page, is_callout=True)
         template_specification["isCallout"] = True
         return self.fill_default_attributes(template_specification)
 
-    def get_adapter_template(self, project_id, algorithm_id, is_upload=False, back_page=None):
+    def get_adapter_template(self, project_id, algorithm_id, is_upload=False, back_page=None, is_callout=False):
         """
         Get the template for an adapter based on the algo group id.
         """
@@ -499,7 +503,7 @@ class FlowController(BaseController):
             submit_link = self.get_url_adapter(algorithm.fk_category, algorithm.id, back_page)
 
         template_specification = self.get_template_for_adapter(project_id, algorithm.fk_category, algorithm,
-                                                               submit_link)
+                                                               submit_link, is_callout=is_callout)
         if template_specification is None:
             return ""
         template_specification[common.KEY_DISPLAY_MENU] = not is_upload
@@ -535,7 +539,7 @@ class FlowController(BaseController):
             op_group = ProjectService.get_operation_group_by_id(operation_id)
             first_op = ProjectService.get_operations_in_group(op_group)[0]
             operation = OperationService.load_operation(int(first_op.id))
-        SimulatorController().copy_simulator_configuration(operation.burst.id)
+        self.simulator_controller.copy_simulator_configuration(operation.burst.id)
 
         raise cherrypy.HTTPRedirect("/burst/")
 
@@ -549,7 +553,7 @@ class FlowController(BaseController):
         is_group = int(is_group) != 0
         if isinstance(remove_after_stop, str):
             remove_after_stop = bool(remove_after_stop)
-        return SimulatorController.cancel_or_remove_operation(operation_id, is_group, remove_after_stop)
+        return self.simulator_controller.cancel_or_remove_operation(operation_id, is_group, remove_after_stop)
 
     def fill_default_attributes(self, template_dictionary, title='-'):
         """
