@@ -29,7 +29,9 @@
 #
 
 import threading
+
 from cherrypy.lib.static import serve_file
+from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
 from tvb.adapters.datatypes.db.simulation_history import SimulationHistoryIndex
 from tvb.adapters.exporters.export_manager import ExportManager
 from tvb.adapters.simulator.coupling_forms import get_form_for_coupling
@@ -43,8 +45,9 @@ from tvb.adapters.simulator.simulator_fragments import *
 from tvb.config.init.introspector_registry import IntrospectionRegistry
 from tvb.core.adapters.abcadapter import ABCAdapter
 from tvb.core.entities.file.files_helper import FilesHelper
-from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel, IntegratorStochasticViewModel, \
-    AdditiveNoiseViewModel, BoldViewModel, RawViewModel
+from tvb.core.entities.file.simulator.view_model import AdditiveNoiseViewModel, BoldViewModel, RawViewModel
+from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel, IntegratorStochasticViewModel
+from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.entities.load import load_entity_by_gid
 from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.storage import dao
@@ -113,7 +116,8 @@ class SimulatorFragmentRenderingRules(object):
                  is_simulation_readonly_load=False, last_form_url=SimulatorWizzardURLs.SET_CONNECTIVITY_URL,
                  last_request_type=GET_REQUEST, is_first_fragment=False, is_launch_fragment=False,
                  is_model_fragment=False, is_surface_simulation=False, is_noise_fragment=False,
-                 is_launch_pse_fragment=False, is_pse_launch=False, monitor_name=None):
+                 is_launch_pse_fragment=False, is_pse_launch=False, monitor_name=None,
+                 is_branch=False):
         """
         :param is_first_fragment: True only for the first form in the wizzard, to hide Previous button
         :param is_launch_fragment: True only for the last form in the wizzard to diplay Launch/SetupPSE/Branch, hide Next
@@ -140,6 +144,7 @@ class SimulatorFragmentRenderingRules(object):
         self.is_launch_pse_fragment = is_launch_pse_fragment
         self.is_pse_launch = is_pse_launch
         self.monitor_name = monitor_name
+        self.is_branch = is_branch
 
     @property
     def load_readonly(self):
@@ -149,6 +154,8 @@ class SimulatorFragmentRenderingRules(object):
 
     @property
     def disable_fields(self):
+        if self.is_branch and not self.include_launch_button:
+            return True
         if self.load_readonly:
             return True
         return False
@@ -203,7 +210,7 @@ class SimulatorFragmentRenderingRules(object):
 
     @property
     def include_branch_button(self):
-        if self.is_launch_fragment and self.is_simulation_copy and not self.is_pse_launch:
+        if self.is_branch and self.is_launch_fragment:
             return True
         return False
 
@@ -220,13 +227,16 @@ class SimulatorFragmentRenderingRules(object):
         return False
 
     def to_dict(self):
-        return {"renderer": self}
+        return {"renderer": self,
+                "showOnlineHelp": common.get_logged_user().is_online_help_active(),
+                "isCallout": False}
 
 
 @traced
 class SimulatorController(BurstBaseController):
     KEY_IS_LOAD_AFTER_REDIRECT = "is_load_after_redirect"
-    DEFAULT_COPY_PREFIX = "copy_of_"
+    COPY_NAME_FORMAT = "copy_of_{}"
+    BRANCH_NAME_FORMAT = "{}_branch{}"
 
     def __init__(self):
         BurstBaseController.__init__(self)
@@ -261,22 +271,21 @@ class SimulatorController(BurstBaseController):
 
         return self.cancel_or_remove_operation(op_id, is_group, remove_after_stop)
 
-    @staticmethod
-    def cancel_or_remove_operation(operation_id, is_group, remove_after_stop=False):
+    def cancel_or_remove_operation(self, operation_id, is_group, remove_after_stop=False):
         """
         Stop the operation given by operation_id. If is_group is true stop all the
         operations from that group.
         """
         # Load before we remove, to have its data in memory here
-        burst_config = BurstService.get_burst_for_operation_id(operation_id)
+        burst_config = BurstService.get_burst_for_operation_id(operation_id, is_group)
         result = OperationService.stop_operation(operation_id, is_group, remove_after_stop)
 
         if remove_after_stop:
             current_burst = common.get_from_session(common.KEY_BURST_CONFIG)
-            if current_burst is not None and burst_config is not None and current_burst.id == burst_config.id:
-                common.remove_from_session(common.KEY_BURST_CONFIG)
-                project = common.get_current_project()
-                common.add2session(common.KEY_BURST_CONFIG, BurstConfiguration(project.id))
+            if (current_burst is not None and burst_config is not None and current_burst.id == burst_config.id and
+                    ((current_burst.fk_simulation == operation_id and not is_group) or
+                     (current_burst.fk_operation_group == operation_id and is_group))):
+                self.reset_simulator_configuration()
         return result
 
     @expose_page
@@ -311,20 +320,28 @@ class SimulatorController(BurstBaseController):
         portlets_list = []  # self.burst_service.get_available_portlets()
         template_specification['portletList'] = portlets_list
         template_specification['selectedPortlets'] = json.dumps(portlets_list)
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
 
         form = self.prepare_first_fragment()
         rendering_rules = SimulatorFragmentRenderingRules(form, SimulatorWizzardURLs.SET_CONNECTIVITY_URL, None,
                                                           is_simulator_copy, is_simulator_load,
                                                           last_form_url=self.last_loaded_form_url,
                                                           last_request_type=cherrypy.request.method,
-                                                          is_first_fragment=True)
-
+                                                          is_first_fragment=True,
+                                                          is_branch=is_branch)
         template_specification.update(**rendering_rules.to_dict())
         return self.fill_default_attributes(template_specification)
 
     def prepare_first_fragment(self):
         adapter_instance = ABCAdapter.build_adapter(self.cached_simulator_algorithm)
-        form = adapter_instance.get_form()('', common.get_current_project().id)
+        form = self.algorithm_service.prepare_adapter_form(adapter_instance=adapter_instance,
+                                                           project_id=common.get_current_project().id,
+                                                           extra_conditions=self._compute_conn_branch_conditions())
+
+        conn_count = dao.count_datatypes(common.get_current_project().id, ConnectivityIndex)
+        if conn_count == 0:
+            form.connectivity.errors.append("No connectivity in the project! Simulation cannot be started without "
+                                            "a connectivity!")
 
         session_stored_simulator = common.get_from_session(common.KEY_SIMULATOR_CONFIG)
         if session_stored_simulator is None:
@@ -334,6 +351,18 @@ class SimulatorController(BurstBaseController):
         form.fill_from_trait(session_stored_simulator)
         return form
 
+    def _compute_conn_branch_conditions(self):
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
+
+        if is_branch:
+            simulator = common.get_from_session(common.KEY_SIMULATOR_CONFIG)
+            conn = dao.get_datatype_by_gid(simulator.connectivity.hex)
+
+            if conn.number_of_regions:
+                return FilterChain(fields=[FilterChain.datatype + '.number_of_regions'],
+                                   operations=["=="], values=[conn.number_of_regions])
+        return None
+
     @expose_fragment('simulator_fragment')
     def set_connectivity(self, **data):
         session_stored_simulator = common.get_from_session(common.KEY_SIMULATOR_CONFIG)
@@ -347,7 +376,8 @@ class SimulatorController(BurstBaseController):
             self.simulator_service.reset_at_connectivity_change(is_simulator_copy, form, session_stored_simulator)
             form.fill_trait(session_stored_simulator)
 
-        next_form = get_form_for_coupling(type(session_stored_simulator.coupling))()
+        next_form = self.algorithm_service.prepare_adapter_form(
+            form_instance=get_form_for_coupling(type(session_stored_simulator.coupling))())
         self.range_parameters.coupling_parameters = next_form.get_range_parameters()
         next_form.fill_from_trait(session_stored_simulator.coupling)
 
@@ -369,29 +399,35 @@ class SimulatorController(BurstBaseController):
             form.fill_from_post(data)
             form.fill_trait(session_stored_simulator.coupling)
 
-        surface_fragment = SimulatorSurfaceFragment('', common.get_current_project().id)
+        surface_fragment = self.algorithm_service.prepare_adapter_form(form_instance=SimulatorSurfaceFragment(),
+                                                                       project_id=common.get_current_project().id)
         surface_fragment.fill_from_trait(session_stored_simulator.surface)
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
 
         rendering_rules = SimulatorFragmentRenderingRules(surface_fragment, SimulatorWizzardURLs.SET_SURFACE_URL,
                                                           SimulatorWizzardURLs.SET_COUPLING_PARAMS_URL,
                                                           is_simulator_copy, is_simulator_load,
-                                                          self.last_loaded_form_url, cherrypy.request.method)
+                                                          self.last_loaded_form_url, cherrypy.request.method,
+                                                          is_branch=is_branch)
+
         return rendering_rules.to_dict()
 
-    @staticmethod
-    def _prepare_cortex_fragment(session_stored_simulator, rendering_rules):
+    def _prepare_cortex_fragment(self, session_stored_simulator, rendering_rules):
         surface_index = load_entity_by_gid(session_stored_simulator.surface.surface_gid)
-        rm_fragment = SimulatorRMFragment('', common.get_current_project().id, surface_index,
-                                          session_stored_simulator.connectivity)
+        rm_fragment = self.algorithm_service.prepare_adapter_form(
+            form_instance=SimulatorRMFragment(surface_index, session_stored_simulator.connectivity),
+            project_id=common.get_current_project().id)
+
         rm_fragment.fill_from_trait(session_stored_simulator.surface)
 
         rendering_rules.form = rm_fragment
         rendering_rules.form_action_url = SimulatorWizzardURLs.SET_CORTEX_URL
         return rendering_rules.to_dict()
 
-    @staticmethod
-    def _prepare_stimulus_fragment(session_stored_simulator, rendering_rules, is_surface_simulation):
-        stimuli_fragment = SimulatorStimulusFragment('', common.get_current_project().id, is_surface_simulation)
+    def _prepare_stimulus_fragment(self, session_stored_simulator, rendering_rules, is_surface_simulation):
+        stimuli_fragment = self.algorithm_service.prepare_adapter_form(
+            form_instance=SimulatorStimulusFragment(is_surface_simulation), project_id=common.get_current_project().id)
+
         stimuli_fragment.fill_from_trait(session_stored_simulator)
 
         rendering_rules.form = stimuli_fragment
@@ -403,12 +439,15 @@ class SimulatorController(BurstBaseController):
         session_stored_simulator = common.get_from_session(common.KEY_SIMULATOR_CONFIG)
         is_simulator_copy = common.get_from_session(common.KEY_IS_SIMULATOR_COPY) or False
         is_simulator_load = common.get_from_session(common.KEY_IS_SIMULATOR_LOAD) or False
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
 
         rendering_rules = SimulatorFragmentRenderingRules(previous_form_action_url=SimulatorWizzardURLs.SET_SURFACE_URL,
                                                           is_simulation_copy=is_simulator_copy,
                                                           is_simulation_readonly_load=is_simulator_load,
                                                           last_form_url=self.last_loaded_form_url,
-                                                          last_request_type=cherrypy.request.method)
+                                                          last_request_type=cherrypy.request.method,
+                                                          is_branch=is_branch)
+
         if cherrypy.request.method == POST_REQUEST:
             form = SimulatorSurfaceFragment()
             form.fill_from_post(data)
@@ -450,19 +489,22 @@ class SimulatorController(BurstBaseController):
 
         if cherrypy.request.method == POST_REQUEST:
             self._update_last_loaded_fragment_url(SimulatorWizzardURLs.SET_MODEL_URL)
-            stimuli_fragment = SimulatorStimulusFragment('', common.get_current_project().id,
-                                                         session_stored_simulator.is_surface_simulation)
+            stimuli_fragment = SimulatorStimulusFragment(session_stored_simulator.is_surface_simulation)
             stimuli_fragment.fill_from_post(data)
             stimuli_fragment.fill_trait(session_stored_simulator)
 
-        model_fragment = SimulatorModelFragment('', common.get_current_project().id)
+        model_fragment = self.algorithm_service.prepare_adapter_form(form_instance=SimulatorModelFragment())
+
         model_fragment.fill_from_trait(session_stored_simulator)
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
 
         rendering_rules = SimulatorFragmentRenderingRules(model_fragment, SimulatorWizzardURLs.SET_MODEL_URL,
                                                           SimulatorWizzardURLs.SET_STIMULUS_URL, is_simulator_copy,
                                                           is_simulator_load, self.last_loaded_form_url,
                                                           cherrypy.request.method, is_model_fragment=True,
-                                                          is_surface_simulation=session_stored_simulator.is_surface_simulation)
+                                                          is_surface_simulation=session_stored_simulator.is_surface_simulation,
+                                                          is_branch=is_branch)
+
         return rendering_rules.to_dict()
 
     @expose_fragment('simulator_fragment')
@@ -477,7 +519,8 @@ class SimulatorController(BurstBaseController):
             form.fill_from_post(data)
             form.fill_trait(session_stored_simulator)
 
-        form = get_form_for_model(type(session_stored_simulator.model))()
+        form = self.algorithm_service.prepare_adapter_form(
+            form_instance=get_form_for_model(type(session_stored_simulator.model))())
         self.range_parameters.model_parameters = form.get_range_parameters()
         form.fill_from_trait(session_stored_simulator.model)
 
@@ -495,18 +538,21 @@ class SimulatorController(BurstBaseController):
 
         if cherrypy.request.method == POST_REQUEST:
             self._update_last_loaded_fragment_url(SimulatorWizzardURLs.SET_INTEGRATOR_URL)
-            form = get_form_for_model(type(session_stored_simulator.model))()
+            form = self.algorithm_service.prepare_adapter_form(
+                form_instance=get_form_for_model(type(session_stored_simulator.model))())
             form.fill_from_post(data)
             form.fill_trait(session_stored_simulator.model)
 
-        integrator_fragment = SimulatorIntegratorFragment('', common.get_current_project().id)
+        integrator_fragment = self.algorithm_service.prepare_adapter_form(form_instance=SimulatorIntegratorFragment())
         integrator_fragment.integrator.display_subform = False
         integrator_fragment.fill_from_trait(session_stored_simulator)
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
 
         rendering_rules = SimulatorFragmentRenderingRules(integrator_fragment, SimulatorWizzardURLs.SET_INTEGRATOR_URL,
                                                           SimulatorWizzardURLs.SET_MODEL_PARAMS_URL, is_simulator_copy,
                                                           is_simulator_load, self.last_loaded_form_url,
-                                                          cherrypy.request.method)
+                                                          cherrypy.request.method, is_branch=is_branch)
+
         return rendering_rules.to_dict()
 
     @expose_fragment('simulator_fragment')
@@ -521,7 +567,9 @@ class SimulatorController(BurstBaseController):
             fragment.fill_from_post(data)
             fragment.fill_trait(session_stored_simulator)
 
-        form = get_form_for_integrator(type(session_stored_simulator.integrator))()
+        form = self.algorithm_service.prepare_adapter_form(
+            form_instance=get_form_for_integrator(type(session_stored_simulator.integrator))())
+
         if hasattr(form, 'noise'):
             form.noise.display_subform = False
         form.fill_from_trait(session_stored_simulator.integrator)
@@ -532,14 +580,15 @@ class SimulatorController(BurstBaseController):
                                                           cherrypy.request.method)
         return rendering_rules.to_dict()
 
-    @staticmethod
-    def _prepare_monitor_form(session_stored_simulator, rendering_rules):
-        monitor_fragment = SimulatorMonitorFragment('', common.get_current_project().id,
-                                                    session_stored_simulator.is_surface_simulation)
+    def _prepare_monitor_form(self, session_stored_simulator, rendering_rules):
+        monitor_fragment = self.algorithm_service.prepare_adapter_form(
+            form_instance=SimulatorMonitorFragment(session_stored_simulator.is_surface_simulation))
         monitor_fragment.fill_from_trait(session_stored_simulator.monitors)
 
         rendering_rules.form = monitor_fragment
         rendering_rules.form_action_url = SimulatorWizzardURLs.SET_MONITORS_URL
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
+        rendering_rules.is_branch = is_branch
         return rendering_rules.to_dict()
 
     @expose_fragment('simulator_fragment')
@@ -666,12 +715,12 @@ class SimulatorController(BurstBaseController):
                                                           type(monitors[first_monitor_index]).__name__)
         return first_monitor_index, last_loaded_fragment_url
 
-    @staticmethod
-    def _prepare_final_fragment(session_stored_simulator, rendering_rules):
+    def _prepare_final_fragment(self, session_stored_simulator, rendering_rules):
         session_stored_burst = common.get_from_session(common.KEY_BURST_CONFIG)
         default_simulation_name, simulation_number = BurstService.prepare_name(session_stored_burst,
                                                                                common.get_current_project().id)
-        form = SimulatorFinalFragment(default_simulation_name=default_simulation_name)
+        form = self.algorithm_service.prepare_adapter_form(
+            form_instance=SimulatorFinalFragment(default_simulation_name=default_simulation_name))
 
         if cherrypy.request.method != POST_REQUEST:
             simulation_name = session_stored_burst.name
@@ -680,11 +729,13 @@ class SimulatorController(BurstBaseController):
             form.fill_from_post({'input_simulation_name_id': simulation_name,
                                  'simulation_length': str(session_stored_simulator.simulation_length)})
 
+        is_branch = common.get_from_session(common.KEY_IS_SIMULATOR_BRANCH)
         form.fill_from_trait(session_stored_simulator)
 
         rendering_rules.form = form
         rendering_rules.form_action_url = SimulatorWizzardURLs.SETUP_PSE_URL
         rendering_rules.is_launch_fragment = True
+        rendering_rules.is_branch = is_branch
         rendering_rules.is_pse_launch = session_stored_burst.is_pse_burst()
         return rendering_rules.to_dict()
 
@@ -707,7 +758,9 @@ class SimulatorController(BurstBaseController):
             self._update_last_loaded_fragment_url(last_loaded_fragment_url)
 
         monitor = session_stored_simulator.monitors[first_monitor_index]
-        form = get_form_for_monitor(type(monitor))(session_stored_simulator, '', common.get_current_project().id)
+        form = self.algorithm_service.prepare_adapter_form(
+            form_instance=get_form_for_monitor(type(monitor))(session_stored_simulator),
+            project_id=common.get_current_project().id)
         form.fill_from_trait(monitor)
 
         rendering_rules = SimulatorFragmentRenderingRules(form, last_loaded_fragment_url,
@@ -729,8 +782,9 @@ class SimulatorController(BurstBaseController):
         if not next_monitor:
             return self._prepare_final_fragment(session_stored_simulator, rendering_rules)
 
-        next_form = get_form_for_monitor(type(next_monitor))(session_stored_simulator, '',
-                                                             common.get_current_project().id)
+        next_form = self.algorithm_service.prepare_adapter_form(
+            form_instance=get_form_for_monitor(type(next_monitor))(session_stored_simulator),
+            project_id=common.get_current_project().id)
         next_form.fill_from_trait(next_monitor)
 
         form_action_url = self.build_monitor_url(SimulatorWizzardURLs.SET_MONITOR_PARAMS_URL,
@@ -826,7 +880,8 @@ class SimulatorController(BurstBaseController):
     def setup_pse(self, **data):
         is_simulator_copy = common.get_from_session(common.KEY_IS_SIMULATOR_COPY) or False
         is_simulator_load = common.get_from_session(common.KEY_IS_SIMULATOR_LOAD) or False
-        next_form = SimulatorPSEConfigurationFragment(self.range_parameters.get_all_range_parameters())
+        next_form = self.algorithm_service.prepare_adapter_form(
+            form_instance=SimulatorPSEConfigurationFragment(self.range_parameters.get_all_range_parameters()))
 
         if cherrypy.request.method == POST_REQUEST:
             session_stored_simulator = common.get_from_session(common.KEY_SIMULATOR_CONFIG)
@@ -865,7 +920,8 @@ class SimulatorController(BurstBaseController):
     def set_pse_params(self, **data):
         is_simulator_copy = common.get_from_session(common.KEY_IS_SIMULATOR_COPY) or False
         is_simulator_load = common.get_from_session(common.KEY_IS_SIMULATOR_LOAD) or False
-        form = SimulatorPSEConfigurationFragment(self.range_parameters.get_all_range_parameters())
+        form = self.algorithm_service.prepare_adapter_form(
+            form_instance=SimulatorPSEConfigurationFragment(self.range_parameters.get_all_range_parameters()))
         burst_config = common.get_from_session(common.KEY_BURST_CONFIG)
 
         if cherrypy.request.method == POST_REQUEST:
@@ -878,10 +934,11 @@ class SimulatorController(BurstBaseController):
             if form.pse_param2.value:
                 param2 = form.pse_param2.value
                 burst_config.range2 = param2.to_json()
+            else:
+                burst_config.range2 = None
         else:
             param1, param2 = self._handle_range_params_at_loading()
-        project_id = common.get_current_project().id
-        next_form = SimulatorPSERangeFragment(param1, param2, project_id=project_id)
+        next_form = self.algorithm_service.prepare_adapter_form(form_instance=SimulatorPSERangeFragment(param1, param2))
 
         rendering_rules = SimulatorFragmentRenderingRules(next_form, SimulatorWizzardURLs.LAUNCH_PSE_URL,
                                                           SimulatorWizzardURLs.SET_PSE_PARAMS_URL,
@@ -905,6 +962,8 @@ class SimulatorController(BurstBaseController):
         if range_param2:
             burst_config.range2 = range_param2.to_json()
         burst_config = self.burst_service.prepare_burst_for_pse(burst_config)
+        session_stored_simulator.operation_group_gid = uuid.UUID(burst_config.operation_group.gid)
+        session_stored_simulator.ranges = json.dumps(burst_config.ranges)
 
         try:
             thread = threading.Thread(target=self.simulator_service.async_launch_and_prepare_pse,
@@ -947,8 +1006,6 @@ class SimulatorController(BurstBaseController):
 
         if launch_mode == self.burst_service.LAUNCH_BRANCH:
             parent_burst = session_burst_config.parent_burst_object
-            count = dao.count_bursts_with_name(parent_burst.name, session_burst_config.fk_project)
-            session_burst_config.name = parent_burst.name + "_" + launch_mode + str(count + 1)
             simulation_state_index = dao.get_generic_entity(SimulationHistoryIndex,
                                                             parent_burst.gid, "fk_parent_burst")
             if simulation_state_index is None or len(simulation_state_index) < 1:
@@ -1026,31 +1083,48 @@ class SimulatorController(BurstBaseController):
 
     @expose_fragment('simulator_fragment')
     def copy_simulator_configuration(self, burst_config_id):
-        burst_config = self.burst_service.load_burst_configuration(burst_config_id)
-        burst_config_copy = burst_config.clone()
-        burst_config_copy.name = self.DEFAULT_COPY_PREFIX + burst_config.name
-
-        project = common.get_current_project()
-        storage_path = self.files_helper.get_project_folder(project, str(burst_config.fk_simulation))
-        simulator = h5.load_view_model(burst_config.simulator_gid, storage_path)
-
-        common.add2session(common.KEY_SIMULATOR_CONFIG, simulator)
+        common.add2session(common.KEY_IS_SIMULATOR_BRANCH, False)
         common.add2session(common.KEY_IS_SIMULATOR_COPY, True)
-        common.add2session(common.KEY_IS_SIMULATOR_LOAD, False)
-        common.add2session(common.KEY_BURST_CONFIG, burst_config_copy)
-
-        self._update_last_loaded_fragment_url(self._prepare_last_fragment_by_burst_type(burst_config_copy))
-        form = self.prepare_first_fragment()
+        form = self._prepare_first_fragment_for_burst_copy(burst_config_id, self.COPY_NAME_FORMAT)
         rendering_rules = SimulatorFragmentRenderingRules(form, SimulatorWizzardURLs.SET_CONNECTIVITY_URL,
                                                           is_simulation_copy=True, is_simulation_readonly_load=True,
                                                           is_first_fragment=True)
         return rendering_rules.to_dict()
 
+    @expose_fragment('simulator_fragment')
+    def branch_simulator_configuration(self, burst_config_id):
+        common.add2session(common.KEY_IS_SIMULATOR_BRANCH, True)
+        common.add2session(common.KEY_IS_SIMULATOR_COPY, False)
+        form = self._prepare_first_fragment_for_burst_copy(burst_config_id, self.BRANCH_NAME_FORMAT)
+        rendering_rules = SimulatorFragmentRenderingRules(form, SimulatorWizzardURLs.SET_CONNECTIVITY_URL,
+                                                          is_simulation_copy=True, is_simulation_readonly_load=True,
+                                                          is_first_fragment=True)
+
+        return rendering_rules.to_dict()
+
+    def _prepare_first_fragment_for_burst_copy(self, burst_config_id, burst_name_format):
+        burst_config = self.burst_service.load_burst_configuration(burst_config_id)
+        burst_config_copy = burst_config.clone()
+        count = dao.count_bursts_with_name(burst_config.name, burst_config.fk_project)
+        burst_config_copy.name = burst_name_format.format(burst_config.name, count + 1)
+
+        project = common.get_current_project()
+        storage_path = self.files_helper.get_project_folder(project, str(burst_config.fk_simulation))
+        simulator = h5.load_view_model(burst_config.simulator_gid, storage_path)
+
+        common.add2session(common.KEY_SIMULATOR_CONFIG, simulator)
+        common.add2session(common.KEY_IS_SIMULATOR_LOAD, False)
+        common.add2session(common.KEY_BURST_CONFIG, burst_config_copy)
+
+        self._update_last_loaded_fragment_url(self._prepare_last_fragment_by_burst_type(burst_config_copy))
+        return self.prepare_first_fragment()
+
     @expose_fragment('simulator_fragment')
     def reset_simulator_configuration(self):
         common.add2session(common.KEY_SIMULATOR_CONFIG, None)
         common.add2session(common.KEY_IS_SIMULATOR_COPY, False)
         common.add2session(common.KEY_IS_SIMULATOR_LOAD, False)
+        common.add2session(common.KEY_IS_SIMULATOR_BRANCH, False)
 
         self._update_last_loaded_fragment_url(SimulatorWizzardURLs.SET_CONNECTIVITY_URL)
         project = common.get_current_project()
