@@ -34,6 +34,7 @@
 """
 
 import json
+
 import cherrypy
 import numpy
 from tvb.adapters.creators.stimulus_creator import *
@@ -60,7 +61,6 @@ LOAD_EXISTING_URL = '/spatial/stimulus/region/load_region_stimulus'
 RELOAD_DEFAULT_PAGE_URL = '/spatial/stimulus/region/reset_region_stimulus'
 
 KEY_REGION_STIMULUS = "stim-region"
-KEY_REGION_STIMULUS_NAME = "stim-region-name"
 
 
 class TemporalPlotForm(EquationPlotForm):
@@ -96,7 +96,7 @@ class RegionStimulusController(SpatioTemporalController):
     @cherrypy.expose
     def set_connectivity(self, **param):
         current_region_stim = common.get_from_session(KEY_REGION_STIMULUS)
-        connectivity_form_field = RegionStimulusCreatorForm(common.get_current_project().id).connectivity
+        connectivity_form_field = RegionStimulusCreatorForm().connectivity
         connectivity_form_field.fill_from_post(param)
         current_region_stim.connectivity = connectivity_form_field.value
         conn_index = load_entity_by_gid(connectivity_form_field.value)
@@ -104,10 +104,11 @@ class RegionStimulusController(SpatioTemporalController):
 
     @cherrypy.expose
     def set_display_name(self, **param):
-        display_name_form_field = StimulusRegionSelectorForm(common.get_current_project().id).display_name
+        display_name_form_field = StimulusRegionSelectorForm().display_name
         display_name_form_field.fill_from_post(param)
         if display_name_form_field.value is not None:
-            common.add2session(KEY_REGION_STIMULUS_NAME, display_name_form_field.value)
+            current_stimulus_region = common.get_from_session(KEY_REGION_STIMULUS)
+            current_stimulus_region.display_name = display_name_form_field.value
 
     @cherrypy.expose
     @using_template('form_fields/form_field')
@@ -138,11 +139,13 @@ class RegionStimulusController(SpatioTemporalController):
         current_stimuli_region = common.get_from_session(KEY_REGION_STIMULUS)
         selected_stimulus_gid = current_stimuli_region.gid.hex
         project_id = common.get_current_project().id
-        region_stim_selector_form = StimulusRegionSelectorForm(project_id)
+        region_stim_selector_form = self.algorithm_service.prepare_adapter_form(
+            form_instance=StimulusRegionSelectorForm(), project_id=common.get_current_project().id)
         region_stim_selector_form.region_stimulus.data = selected_stimulus_gid
-        region_stim_selector_form.display_name.data = common.get_from_session(KEY_REGION_STIMULUS_NAME)
+        region_stim_selector_form.display_name.data = current_stimuli_region.display_name
 
-        region_stim_creator_form = RegionStimulusCreatorForm(project_id)
+        region_stim_creator_form = self.algorithm_service.prepare_adapter_form(
+            form_instance=RegionStimulusCreatorForm(), project_id=common.get_current_project().id)
         if not hasattr(current_stimuli_region, 'connectivity') or not current_stimuli_region.connectivity:
             conn = try_get_last_datatype(project_id, ConnectivityIndex)
             if conn is None:
@@ -173,9 +176,10 @@ class RegionStimulusController(SpatioTemporalController):
         Generate the required template dictionary for the second step.
         """
         current_region_stimulus = common.get_from_session(KEY_REGION_STIMULUS)
-        region_stim_selector_form = StimulusRegionSelectorForm(common.get_current_project().id)
+        region_stim_selector_form = self.algorithm_service.prepare_adapter_form(
+            form_instance=StimulusRegionSelectorForm(), project_id=common.get_current_project().id)
         region_stim_selector_form.region_stimulus.data = current_region_stimulus.gid.hex
-        region_stim_selector_form.display_name.data = common.get_from_session(KEY_REGION_STIMULUS_NAME)
+        region_stim_selector_form.display_name.data = current_region_stimulus.display_name
 
         template_specification = dict(title="Spatio temporal - Region stimulus")
         template_specification['mainContent'] = 'spatial/stimulus_region_step2_main'
@@ -223,7 +227,6 @@ class RegionStimulusController(SpatioTemporalController):
         # TODO: proper init
         new_region_stimulus.weight = numpy.array([])
         common.add2session(KEY_REGION_STIMULUS, new_region_stimulus)
-        common.add2session(KEY_REGION_STIMULUS_NAME, None)
 
     @expose_page
     def step_1_submit(self, next_step, do_reset=0, **kwargs):
@@ -265,8 +268,6 @@ class RegionStimulusController(SpatioTemporalController):
         Creates a stimulus from the given data.
         """
         current_stimulus_region = common.get_from_session(KEY_REGION_STIMULUS)
-        display_name = common.get_from_session(KEY_REGION_STIMULUS_NAME)
-        current_stimulus_region.display_name = display_name
         region_stimulus_creator = ABCAdapter.build_adapter_from_class(RegionStimulusCreator)
         self.operation_service.fire_operation(region_stimulus_creator, common.get_logged_user(),
                                               common.get_current_project().id, view_model=current_stimulus_region)
@@ -327,9 +328,9 @@ class RegionStimulusController(SpatioTemporalController):
 
         dummy_gid = uuid.UUID(existent_region_stimulus_index.fk_connectivity_gid)
         stimuli_region.connectivity = dummy_gid
+        stimuli_region.display_name = existent_region_stimulus_index.user_tag_1
 
         common.add2session(KEY_REGION_STIMULUS, stimuli_region)
-        common.add2session(KEY_REGION_STIMULUS_NAME, existent_region_stimulus_index.user_tag_1)
         return stimuli_region
 
     @expose_page
