@@ -56,10 +56,10 @@ class TestAdapter3Form(abcadapter.ABCAdapterForm):
         This class is used for testing purposes.
     """
 
-    def __init__(self, prefix='', project_id=None):
-        super(TestAdapter3Form, self).__init__(prefix, project_id)
-        self.param_5 = IntField(TestModel.param_5, self, name='param_5')
-        self.param_6 = IntField(TestModel.param_6, self, name='param_6')
+    def __init__(self):
+        super(TestAdapter3Form, self).__init__()
+        self.param_5 = IntField(TestModel.param_5, name='param_5')
+        self.param_6 = IntField(TestModel.param_6, name='param_6')
 
     @staticmethod
     def get_view_model():
@@ -125,9 +125,9 @@ class TestAdapterHugeMemoryRequiredForm(abcadapter.ABCAdapterForm):
         This class is used for testing purposes.
     """
 
-    def __init__(self, prefix='', project_id=None):
-        super(TestAdapterHugeMemoryRequiredForm, self).__init__(prefix, project_id)
-        self.test = IntField(TestModelRequired.test, self, name='test')
+    def __init__(self):
+        super(TestAdapterHugeMemoryRequiredForm, self).__init__()
+        self.test = IntField(TestModelRequired.test, name='test')
 
     @staticmethod
     def get_view_model():
@@ -178,9 +178,9 @@ class TestAdapterHDDRequiredForm(abcadapter.ABCAdapterForm):
         This class is used for testing purposes.
     """
 
-    def __init__(self, prefix='', project_id=None):
-        super(TestAdapterHDDRequiredForm, self).__init__(prefix, project_id)
-        self.test = IntField(TestModelRequired.test, self, name='test')
+    def __init__(self):
+        super(TestAdapterHDDRequiredForm, self).__init__()
+        self.test = IntField(TestModelRequired.test, name='test')
 
     @staticmethod
     def get_view_model():
